@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Create a XPI language pack from Mozilla sources and translated l10n files.
+"""
+Create a XPI language pack from Mozilla sources and translated l10n files.
 This script has only been tested with Firefox 3.1 beta sources.
 
 (Basically the process described at
@@ -50,22 +51,21 @@ from shutil import move, rmtree
 from subprocess import PIPE, CalledProcessError, Popen
 from tempfile import mkdtemp
 
-
 logger = logging.getLogger(__name__)
 
 
 class RunProcessError(CalledProcessError):
-    """Subclass of CalledProcessError exception with custom message strings"""
+    """Subclass of CalledProcessError exception with custom message strings."""
 
     _default_message = "Command '%s' returned exit status %d"
 
     def __init__(self, message=None, **kwargs):
-        """Use and strip string message='' from kwargs"""
+        """Use and strip string message='' from kwargs."""
         self._message = message or self._default_message
         super().__init__(**kwargs)
 
     def __str__(self):
-        """Format exception message string (avoiding TypeErrors)"""
+        """Format exception message string (avoiding TypeErrors)."""
         output = ""
         message = self._message
         if message.count("%") != 2:
@@ -77,7 +77,7 @@ class RunProcessError(CalledProcessError):
 
 
 def run(cmd, expected_status=0, fail_msg=None, stdout=-1, stderr=-1):
-    """Run a command"""
+    """Run a command."""
     # Default is to capture (and log) std{out,error} unless run as script
     if __name__ == "__main__" or logger.getEffectiveLevel() == logging.DEBUG:
         std = None
@@ -180,17 +180,25 @@ ac_add_options --enable-application={product}
         # make langpack-cy LOCALE_MERGEDIR=$PWD/merge-cy
         for lang in langs:
             run(
-                ["make", "-C", os.path.join(product, "locales")]
-                + ["merge-%s" % lang]
-                + [f"LOCALE_MERGEDIR={mergedir}/merge-{lang}"]
-                + moz_app_version,
+                [
+                    "make",
+                    "-C",
+                    os.path.join(product, "locales"),
+                    "merge-%s" % lang,
+                    f"LOCALE_MERGEDIR={mergedir}/merge-{lang}",
+                    *moz_app_version,
+                ],
                 fail_msg="Unable to merge XPI!",
             )
             run(
-                ["make", "-C", os.path.join(product, "locales")]
-                + ["langpack-%s" % lang]
-                + [f"LOCALE_MERGEDIR={mergedir}/merge-{lang}"]
-                + moz_app_version,
+                [
+                    "make",
+                    "-C",
+                    os.path.join(product, "locales"),
+                    "langpack-%s" % lang,
+                    f"LOCALE_MERGEDIR={mergedir}/merge-{lang}",
+                    *moz_app_version,
+                ],
                 fail_msg="Unable to successfully build XPI!",
             )
 
