@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2003-2008 Zuza Software Foundation
 #
@@ -19,35 +17,36 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 
-"""Convert an OpenOffice.org (SDF) localization file to XLIFF localization files.
+"""
+Convert an OpenOffice.org (SDF) localization file to XLIFF localization files.
 
 See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/oo2po.html
 for examples and usage instructions.
 """
 
-import sys
 import logging
-from urllib import urlencode
 
-from translate.storage import xliff
-from translate.storage import oo
+from translate.storage import oo, xliff
 
 # TODO: support using one GSI file as template, another as input (for when English is in one and translation in another)
 
 logger = logging.getLogger(__name__)
 
-class oo2xliff:
 
-    def __init__(self, sourcelanguage, targetlanguage, blankmsgstr=False, long_keys=False):
-        """construct an oo2xliff converter for the specified languages"""
+class oo2xliff:
+    def __init__(
+        self, sourcelanguage, targetlanguage, blankmsgstr=False, long_keys=False
+    ):
+        """Construct an oo2xliff converter for the specified languages."""
         self.sourcelanguage = sourcelanguage
         self.targetlanguage = targetlanguage
         self.blankmsgstr = blankmsgstr
         self.long_keys = long_keys
 
-    def maketargetunit(self, part1, part2, translators_comment, key, subkey):
-        """makes a base unit (.po or XLIFF) out of a subkey of two parts"""
-        #TODO: Do better
+    @staticmethod
+    def maketargetunit(part1, part2, translators_comment, key, subkey):
+        """Makes a base unit (.po or XLIFF) out of a subkey of two parts."""
+        # TODO: Do better
         text1 = getattr(part1, subkey)
         if text1 == "":
             return None
@@ -59,28 +58,30 @@ class oo2xliff:
             unit.markfuzzy(False)
         else:
             unit.markfuzzy(True)
-        unit.addlocation(key + "." + subkey)
+        unit.setid(key + "." + subkey)
         if getattr(translators_comment, subkey).strip() != "":
             unit.addnote(getattr(translators_comment, subkey), origin="developer")
         return unit
 
     def convertelement(self, theoo):
-        """convert an oo element into a list of base units (.po or XLIFF)"""
+        """Convert an oo element into a list of base units (.po or XLIFF)."""
         if self.sourcelanguage in theoo.languages:
             part1 = theoo.languages[self.sourcelanguage]
         else:
-            logging.error("/".join(theoo.lines[0].getkey()) +
-                          "language not found: %s", self.sourcelanguage)
+            logging.error(
+                "%s language not found: %s",
+                "/".join(theoo.lines[0].getkey()),
+                self.sourcelanguage,
+            )
             return []
         if self.blankmsgstr:
             # use a blank part2
             part2 = oo.ooline()
+        elif self.targetlanguage in theoo.languages:
+            part2 = theoo.languages[self.targetlanguage]
         else:
-            if self.targetlanguage in theoo.languages:
-                part2 = theoo.languages[self.targetlanguage]
-            else:
-                # if the language doesn't exist, the translation is missing ... so make it blank
-                part2 = oo.ooline()
+            # if the language doesn't exist, the translation is missing ... so make it blank
+            part2 = oo.ooline()
         if "x-comment" in theoo.languages:
             translators_comment = theoo.languages["x-comment"]
         else:
@@ -94,19 +95,10 @@ class oo2xliff:
         return unitlist
 
     def convertstore(self, theoofile, duplicatestyle="msgctxt"):
-        """converts an entire oo file to a base class format (.po or XLIFF)"""
+        """Converts an entire oo file to a base class format (.po or XLIFF)."""
         thetargetfile = xliff.xlifffile()
         thetargetfile.setsourcelanguage(self.sourcelanguage)
         thetargetfile.settargetlanguage(self.targetlanguage)
-        # create a header for the file
-        bug_url = 'http://qa.openoffice.org/issues/enter_bug.cgi?%s' % \
-                  urlencode({"subcomponent": "ui",
-                             "comment": "",
-                             "short_desc": "Localization issue in file: %s" % \
-                                           theoofile.filename,
-                             "component": "l10n",
-                             "form_name": "enter_issue",
-                            })
         # go through the oo and convert each element
         for theoo in theoofile.units:
             unitlist = self.convertelement(theoo)
@@ -116,13 +108,22 @@ class oo2xliff:
 
 
 def verifyoptions(options):
-    """verifies the commandline options"""
+    """Verifies the commandline options."""
     if not options.targetlanguage:
         raise ValueError("You must specify the target language.")
 
 
-def convertoo(inputfile, outputfile, templates, pot=False, sourcelanguage=None, targetlanguage=None, duplicatestyle="msgctxt", multifilestyle="single"):
-    """reads in stdin using inputstore class, converts using convertorclass, writes to stdout"""
+def convertoo(
+    inputfile,
+    outputfile,
+    templates,
+    pot=False,
+    sourcelanguage=None,
+    targetlanguage=None,
+    duplicatestyle="msgctxt",
+    multifilestyle="single",
+):
+    """Reads in stdin using inputstore class, converts using convertorclass, writes to stdout."""
     inputstore = oo.oofile()
     if hasattr(inputfile, "filename"):
         inputfilename = inputfile.filename
@@ -132,49 +133,72 @@ def convertoo(inputfile, outputfile, templates, pot=False, sourcelanguage=None,
     inputstore.parse(inputfile.read())
     if not sourcelanguage:
         testlangtype = targetlanguage or (inputstore and inputstore.languages[0]) or ""
-        if testlangtype.isdigit():
-            sourcelanguage = "01"
-        else:
-            sourcelanguage = "en-US"
-    if not sourcelanguage in inputstore.languages:
-        logger.warning("sourcelanguage '%s' not found in inputfile '%s' "
-                       "(contains %s)",
-                       sourcelanguage, inputfilename,
-                       ", ".join(inputstore.languages))
-    if not pot and (targetlanguage and
-                    targetlanguage not in inputstore.languages):
-        logger.warning("targetlanguage '%s' not found in inputfile '%s' "
-                       "(contains %s)",
-                       targetlanguage, inputfilename,
-                       ", ".join(inputstore.languages))
-    convertor = oo2xliff(sourcelanguage, targetlanguage, blankmsgstr=pot,
-                         long_keys=(multifilestyle != "single"))
+        sourcelanguage = "01" if testlangtype.isdigit() else "en-US"
+    if sourcelanguage not in inputstore.languages:
+        logger.warning(
+            "sourcelanguage '%s' not found in inputfile '%s' (contains %s)",
+            sourcelanguage,
+            inputfilename,
+            ", ".join(inputstore.languages),
+        )
+    if not pot and (targetlanguage and targetlanguage not in inputstore.languages):
+        logger.warning(
+            "targetlanguage '%s' not found in inputfile '%s' (contains %s)",
+            targetlanguage,
+            inputfilename,
+            ", ".join(inputstore.languages),
+        )
+    convertor = oo2xliff(
+        sourcelanguage,
+        targetlanguage,
+        blankmsgstr=pot,
+        long_keys=(multifilestyle != "single"),
+    )
     outputstore = convertor.convertstore(inputstore, duplicatestyle)
     if outputstore.isempty():
         return 0
-    outputfile.write(str(outputstore))
+    outputstore.serialize(outputfile)
     return 1
 
 
 def main(argv=None):
     from translate.convert import convert
-    formats = {
-                "oo": ("xlf", convertoo),
-                "sdf": ("xlf", convertoo),
-              }
+
+    formats = (
+        ("oo", ("xlf", convertoo)),
+        ("sdf", ("xlf", convertoo)),
+        ("oo", ("xliff", convertoo)),
+        ("sdf", ("xliff", convertoo)),
+    )
     # always treat the input as an archive unless it is a directory
     archiveformats = {(None, "input"): oo.oomultifile}
-    parser = convert.ArchiveConvertOptionParser(formats, usepots=False,
-                                                description=__doc__,
-                                                archiveformats=archiveformats)
-    parser.add_option("-l", "--language", dest="targetlanguage", default=None,
-                      help="set target language to extract from oo file (e.g. af-ZA)",
-                      metavar="LANG")
-    parser.add_option("", "--source-language", dest="sourcelanguage", default=None,
-            help="set source language code (default en-US)", metavar="LANG")
-    parser.add_option("", "--nonrecursiveinput", dest="allowrecursiveinput",
-                      default=True, action="store_false",
-                      help="don't treat the input oo as a recursive store")
+    parser = convert.ArchiveConvertOptionParser(
+        formats, usepots=False, description=__doc__, archiveformats=archiveformats
+    )
+    parser.add_option(
+        "-l",
+        "--language",
+        dest="targetlanguage",
+        default=None,
+        help="set target language to extract from oo file (e.g. af-ZA)",
+        metavar="LANG",
+    )
+    parser.add_option(
+        "",
+        "--source-language",
+        dest="sourcelanguage",
+        default=None,
+        help="set source language code (default en-US)",
+        metavar="LANG",
+    )
+    parser.add_option(
+        "",
+        "--nonrecursiveinput",
+        dest="allowrecursiveinput",
+        default=True,
+        action="store_false",
+        help="don't treat the input oo as a recursive store",
+    )
     parser.add_duplicates_option()
     parser.add_multifile_option()
     parser.passthrough.append("sourcelanguage")
@@ -183,5 +207,5 @@ def main(argv=None):
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
