@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Convert Gettext PO localization files to an OpenOffice.org (SDF) localization file.
+"""
+Convert Gettext PO localization files to an OpenOffice.org (SDF) localization file.
 
 See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/oo2po.html
 for examples and usage instructions.
@@ -30,7 +31,6 @@ from translate.convert import convert
 from translate.filters import autocorrect, checks, pofilter
 from translate.storage import factory, oo
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -44,7 +44,7 @@ class reoo:
         long_keys=False,
         filteraction="exclude",
     ):
-        """construct a reoo converter for the specified languages (timestamp=0 means leave unchanged)"""
+        """Construct a reoo converter for the specified languages (timestamp=0 means leave unchanged)."""
         # languages is a pair of language ids
         self.long_keys = long_keys
         self.readoo(templatefile)
@@ -61,14 +61,14 @@ class reoo:
         self.includefuzzy = includefuzzy
 
     def makeindex(self):
-        """makes an index of the oo keys that are used in the source file"""
+        """Makes an index of the oo keys that are used in the source file."""
         self.index = {}
         for ookey, theoo in self.o.ookeys.items():
             sourcekey = oo.makekey(ookey, self.long_keys)
             self.index[sourcekey] = theoo
 
     def readoo(self, of):
-        """read in the oo from the file"""
+        """Read in the oo from the file."""
         oosrc = of.read()
         self.o = oo.oofile()
         self.o.parse(oosrc)
@@ -105,7 +105,7 @@ class reoo:
                     logger.warning("error outputting source unit %r", str(unit))
 
     def applytranslation(self, key, subkey, theoo, unit):
-        """applies the translation from the source unit to the oo unit"""
+        """Applies the translation from the source unit to the oo unit."""
         if not self.includefuzzy and unit.isfuzzy():
             return
         makecopy = False
@@ -156,7 +156,7 @@ def getmtime(filename):
 
 class oocheckfilter(pofilter.pocheckfilter):
     def validelement(self, unit, filename, filteraction):
-        """Returns whether or not to use unit in conversion. (filename is just for error reporting)"""
+        """Returns whether or not to use unit in conversion. (filename is just for error reporting)."""
         if filteraction == "none":
             return True
         filterresult = self.filterunit(unit)
@@ -221,22 +221,18 @@ def convertoo(
     if not targetlanguage:
         raise ValueError("You must specify the target language")
     if not sourcelanguage:
-        if targetlanguage.isdigit():
-            sourcelanguage = "01"
-        else:
-            sourcelanguage = "en-US"
+        sourcelanguage = "01" if targetlanguage.isdigit() else "en-US"
     languages = (sourcelanguage, targetlanguage)
     if templatefile is None:
         raise ValueError("must have template file for oo files")
-    else:
-        convertor = reoo(
-            templatefile,
-            languages=languages,
-            timestamp=timestamp,
-            includefuzzy=includefuzzy,
-            long_keys=multifilestyle != "single",
-            filteraction=filteraction,
-        )
+    convertor = reoo(
+        templatefile,
+        languages=languages,
+        timestamp=timestamp,
+        includefuzzy=includefuzzy,
+        long_keys=multifilestyle != "single",
+        filteraction=filteraction,
+    )
     outputstore = convertor.convertstore(inputstore)
     # TODO: check if we need to manually delete missing items
     outputstore.serialize(outputfile, skip_source, targetlanguage)
