@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Convert Gettext PO localization files to Java/Mozilla .properties files.
+"""
+Convert Gettext PO localization files to Java/Mozilla .properties files.
 
 See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/prop2po.html
 for examples and usage instructions.
@@ -28,46 +29,48 @@ from translate.convert import accesskey, convert
 from translate.misc import quote
 from translate.storage import po, properties
 
-
 eol = "\n"
 
 
 def applytranslation(key, propunit, inunit, mixedkeys):
-    """applies the translation for key in the po unit to the prop unit"""
+    """Applies the translation for key in the po unit to the prop unit."""
     # this converts the po-style string to a prop-style string
     value = inunit.target
     # handle mixed keys
     for labelsuffix in properties.labelsuffixes:
-        if key.endswith(labelsuffix):
-            if key in mixedkeys:
-                value, akey = accesskey.extract(value)
-                break
+        if key.endswith(labelsuffix) and key in mixedkeys:
+            value, akey = accesskey.extract(value)
+            break
     else:
         for akeysuffix in properties.accesskeysuffixes:
-            if key.endswith(akeysuffix):
-                if key in mixedkeys:
-                    label, value = accesskey.extract(value)
-                    if not value:
-                        warnings.warn("Could not find accesskey for %s" % key)
-                        # Use the source language accesskey
-                        label, value = accesskey.extract(inunit.source)
-                    else:
-                        original = propunit.source
-                        # For the sake of diffs we keep the case of the
-                        # accesskey the same if we know the translation didn't
-                        # change. Casing matters in XUL.
-                        if value == propunit.source and original.lower() == value.lower():
-                            if original.isupper():
-                                value = value.upper()
-                            elif original.islower():
-                                value = value.lower()
+            if key.endswith(akeysuffix) and key in mixedkeys:
+                label, value = accesskey.extract(value)
+                if not value:
+                    warnings.warn("Could not find accesskey for %s" % key)
+                    # Use the source language accesskey
+                    label, value = accesskey.extract(inunit.source)
+                else:
+                    original = propunit.source
+                    # For the sake of diffs we keep the case of the
+                    # accesskey the same if we know the translation didn't
+                    # change. Casing matters in XUL.
+                    if value == propunit.source and original.lower() == value.lower():
+                        if original.isupper():
+                            value = value.upper()
+                        elif original.islower():
+                            value = value.lower()
     return value
 
 
 class reprop:
-
-    def __init__(self, templatefile, inputstore, personality, encoding=None,
-                 remove_untranslated=False):
+    def __init__(
+        self,
+        templatefile,
+        inputstore,
+        personality,
+        encoding=None,
+        remove_untranslated=False,
+    ):
         self.templatefile = templatefile
         self.inputstore = inputstore
         self.personality = properties.get_dialect(personality)
@@ -75,8 +78,9 @@ class reprop:
         if self.encoding is None:
             self.encoding = self.personality.default_encoding
         self.remove_untranslated = remove_untranslated
-        self.mixer = accesskey.UnitMixer(properties.labelsuffixes,
-                                         properties.accesskeysuffixes)
+        self.mixer = accesskey.UnitMixer(
+            properties.labelsuffixes, properties.accesskeysuffixes
+        )
 
     def convertstore(self, includefuzzy=False):
         self.includefuzzy = includefuzzy
@@ -111,6 +115,7 @@ class reprop:
     def _explode_gaia_plurals(self):
         """Explode the gaia plurals."""
         from translate.lang import data
+
         for unit in self.inputstore.units:
             if not unit.hasplural():
                 continue
@@ -122,11 +127,11 @@ class reprop:
             for category, text in zip(names, unit.target.strings):
                 # TODO: for now we assume all forms are present. We need to
                 # fill in the rest after mapping things to the proper CLDR names.
-                if category == 'zero':
+                if category == "zero":
                     # [zero] cases are translated as separate units
                     continue
                 new_unit = self.inputstore.addsourceunit("fish")  # not used
-                new_location = '%s[%s]' % (location, category)
+                new_location = f"{location}[{category}]"
                 new_unit.addlocation(new_location)
                 new_unit.target = text
                 self.inputstore.locationindex[new_location] = new_unit
@@ -138,14 +143,15 @@ class reprop:
         """Explode the gwt plurals."""
         # cldr names to GWT variants
         cldr2gwt = {
-            'zero': 'none',
-            'one': 'one',
-            'two': 'two',
-            'few': 'few',
-            'many': 'many',
-            'other': '',
+            "zero": "none",
+            "one": "one",
+            "two": "two",
+            "few": "few",
+            "many": "many",
+            "other": "",
         }
         from translate.lang import data
+
         for unit in self.inputstore.units:
             if not unit.hasplural():
                 continue
@@ -157,10 +163,10 @@ class reprop:
             location = unit.getlocations()[0]
             for category, text in zip(names, unit.target.strings):
                 new_unit = self.inputstore.addsourceunit("fish")  # not used
-                if category != '':
-                    new_location = '%s[%s]' % (location, category)
+                if category != "":
+                    new_location = f"{location}[{category}]"
                 else:
-                    new_location = '%s' % (location)
+                    new_location = "%s" % (location)
                 new_unit.addlocation(new_location)
                 new_unit.target = text
                 self.inputstore.locationindex[new_location] = new_unit
@@ -171,17 +177,17 @@ class reprop:
         if self.inmultilinemsgid:
             msgid = quote.rstripeol(line).strip()
             # see if there's more
-            self.inmultilinemsgid = (msgid[-1:] == '\\')
+            self.inmultilinemsgid = msgid[-1:] == "\\"
             # if we're echoing...
             if self.inecho:
                 returnline = line
         # otherwise, this could be a comment
-        elif line.strip()[:1] == '#':
+        elif line.strip()[:1] == "#":
             returnline = quote.rstripeol(line) + eol
         else:
             line = quote.rstripeol(line)
             delimiter_char, delimiter_pos = self.personality.find_delimiter(line)
-            if quote.rstripeol(line)[-1:] == '\\':
+            if quote.rstripeol(line)[-1:] == "\\":
                 self.inmultilinemsgid = True
             if delimiter_pos == -1:
                 key = self.personality.key_strip(line)
@@ -189,31 +195,48 @@ class reprop:
             else:
                 key = self.personality.key_strip(line[:delimiter_pos])
                 # Calculate space around the equal sign
-                prespace = line[line.find(' ', len(key)):delimiter_pos]
-                postspacestart = len(line[delimiter_pos+1:])
-                postspaceend = len(line[delimiter_pos+1:].lstrip())
-                postspace = line[delimiter_pos+1:delimiter_pos+(postspacestart-postspaceend)+1]
+                prespace = line[line.find(" ", len(key)) : delimiter_pos]
+                postspacestart = len(line[delimiter_pos + 1 :])
+                postspaceend = len(line[delimiter_pos + 1 :].lstrip())
+                postspace = line[
+                    delimiter_pos + 1 : delimiter_pos
+                    + (postspacestart - postspaceend)
+                    + 1
+                ]
                 delimiter = prespace + delimiter_char + postspace
             if key in self.inputstore.locationindex:
                 unit = self.inputstore.locationindex[key]
-                if unit is None or not unit.istranslated() and bool(unit.source) and self.remove_untranslated:
+                if (
+                    unit is None
+                    or not unit.istranslated()
+                    and bool(unit.source)
+                    and self.remove_untranslated
+                ):
                     returnline = ""
                     self.inecho = False
                 else:
-                    if unit.isfuzzy() and not self.includefuzzy or len(unit.target) == 0:
+                    if (
+                        unit.isfuzzy()
+                        and not self.includefuzzy
+                        or len(unit.target) == 0
+                    ):
                         value = unit.source
                     else:
                         value = self._handle_accesskeys(unit, key)
                     self.inecho = False
                     assert isinstance(value, str)
                     returnline = "%(key)s%(del)s%(value)s%(term)s%(eol)s" % {
-                        "key": "%s%s%s" % (self.personality.key_wrap_char,
-                                           key,
-                                           self.personality.key_wrap_char),
+                        "key": "{}{}{}".format(
+                            self.personality.key_wrap_char,
+                            key,
+                            self.personality.key_wrap_char,
+                        ),
                         "del": delimiter if delimiter_pos != -1 or value else "",
-                        "value": "%s%s%s" % (self.personality.value_wrap_char,
-                                             self.personality.encode(value),
-                                             self.personality.value_wrap_char),
+                        "value": "{}{}{}".format(
+                            self.personality.value_wrap_char,
+                            self.personality.encode(value),
+                            self.personality.value_wrap_char,
+                        ),
                         "term": self.personality.pair_terminator,
                         "eol": eol,
                     }
@@ -224,29 +247,59 @@ class reprop:
         return returnline
 
 
-def convertstrings(inputfile, outputfile, templatefile, personality="strings",
-                   includefuzzy=False, encoding=None, outputthreshold=None,
-                   remove_untranslated=False):
-    """.strings specific convertor function"""
-    return convertprop(inputfile, outputfile, templatefile,
-                       personality="strings", includefuzzy=includefuzzy,
-                       encoding=encoding, outputthreshold=outputthreshold,
-                       remove_untranslated=remove_untranslated)
+def convertstrings(
+    inputfile,
+    outputfile,
+    templatefile,
+    personality="strings",
+    includefuzzy=False,
+    encoding=None,
+    outputthreshold=None,
+    remove_untranslated=False,
+):
+    """.strings specific convertor function."""
+    return convertprop(
+        inputfile,
+        outputfile,
+        templatefile,
+        personality="strings",
+        includefuzzy=includefuzzy,
+        encoding=encoding,
+        outputthreshold=outputthreshold,
+        remove_untranslated=remove_untranslated,
+    )
 
 
-def convertmozillaprop(inputfile, outputfile, templatefile,
-                       includefuzzy=False, remove_untranslated=False,
-                       outputthreshold=None):
-    """Mozilla specific convertor function"""
-    return convertprop(inputfile, outputfile, templatefile,
-                       personality="mozilla", includefuzzy=includefuzzy,
-                       remove_untranslated=remove_untranslated,
-                       outputthreshold=outputthreshold)
+def convertmozillaprop(
+    inputfile,
+    outputfile,
+    templatefile,
+    includefuzzy=False,
+    remove_untranslated=False,
+    outputthreshold=None,
+):
+    """Mozilla specific convertor function."""
+    return convertprop(
+        inputfile,
+        outputfile,
+        templatefile,
+        personality="mozilla",
+        includefuzzy=includefuzzy,
+        remove_untranslated=remove_untranslated,
+        outputthreshold=outputthreshold,
+    )
 
 
-def convertprop(inputfile, outputfile, templatefile, personality="java",
-                includefuzzy=False, encoding=None, remove_untranslated=False,
-                outputthreshold=None):
+def convertprop(
+    inputfile,
+    outputfile,
+    templatefile,
+    personality="java",
+    includefuzzy=False,
+    encoding=None,
+    remove_untranslated=False,
+    outputthreshold=None,
+):
     inputstore = po.pofile(inputfile)
 
     if not convert.should_output_store(inputstore, outputthreshold):
@@ -254,10 +307,9 @@ def convertprop(inputfile, outputfile, templatefile, personality="java",
 
     if templatefile is None:
         raise ValueError("must have template file for properties files")
-        # convertor = po2prop()
-    else:
-        convertor = reprop(templatefile, inputstore, personality, encoding,
-                           remove_untranslated)
+    convertor = reprop(
+        templatefile, inputstore, personality, encoding, remove_untranslated
+    )
     outputprop = convertor.convertstore(includefuzzy)
     outputfile.write(outputprop)
     return True
@@ -272,19 +324,29 @@ formats = {
 
 def main(argv=None):
     # handle command line options
-    parser = convert.ConvertOptionParser(formats, usetemplates=True,
-                                         description=__doc__)
+    parser = convert.ConvertOptionParser(
+        formats, usetemplates=True, description=__doc__
+    )
     parser.add_option(
-        "", "--personality", dest="personality",
-        default=properties.default_dialect, type="choice",
+        "",
+        "--personality",
+        dest="personality",
+        default=properties.default_dialect,
+        type="choice",
         choices=list(properties.dialects),
-        help="override the input file format: %s (for .properties files, default: %s)" % (
-            ", ".join(properties.dialects), properties.default_dialect),
-        metavar="TYPE")
+        help="override the input file format: {} (for .properties files, default: {})".format(
+            ", ".join(properties.dialects), properties.default_dialect
+        ),
+        metavar="TYPE",
+    )
     parser.add_option(
-        "", "--encoding", dest="encoding", default=None,
+        "",
+        "--encoding",
+        dest="encoding",
+        default=None,
         help="override the encoding set by the personality",
-        metavar="ENCODING")
+        metavar="ENCODING",
+    )
     parser.add_threshold_option()
     parser.add_fuzzy_option()
     parser.add_remove_untranslated_option()
@@ -293,5 +355,5 @@ def main(argv=None):
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
