@@ -15,7 +15,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
-"""Convert Gettext PO localization files back to Windows Resource (.rc) files.
+"""
+Convert Gettext PO localization files back to Windows Resource (.rc) files.
 
 See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/rc2po.html
 for examples and usage instructions.
@@ -30,10 +31,9 @@ from translate.storage.rc import (
     generate_menu_pre_name,
     generate_popup_caption_name,
     generate_popup_pre_name,
+    rcfile,
 )
 
-
-NL = "\r\n"
 BLOCK_START = "BEGIN"
 BLOCK_END = "END"
 
@@ -47,7 +47,10 @@ def is_iterable_but_not_string(o):
 
 class rerc:
     def __init__(self, templatefile, charset="utf-8", lang=None, sublang=None):
-        self.templatefile = templatefile
+        self.templatecontent = templatefile.read()
+        self.templatestore = rcfile()
+        self.templatestore.charset = charset
+        self.templatestore.parse(self.templatecontent)
         self.inputdict = {}
         self.charset = charset
         self.lang = lang
@@ -62,51 +65,55 @@ class rerc:
             comment = comment[:-1]
         yield comment
 
+    def convert_caption(self, toks, name):
+        yield "CAPTION "
+
+        msgid = toks.caption[1:-1]
+        if msgid in self.inputdict:
+            if name in self.inputdict[msgid]:
+                yield '"' + self.inputdict[msgid][name] + '"'
+            elif EMPTY_LOCATION in self.inputdict[msgid]:
+                yield '"' + self.inputdict[msgid][EMPTY_LOCATION] + '"'
+        else:
+            yield toks.caption
+
+    def convert_block_options(self, s, loc, toks, name=None):
+        for option in toks:
+            yield " "
+            if option.language:
+                yield from self.convert_language(s, loc, option)
+            elif option.caption:
+                yield from self.convert_caption(option, name)
+            else:
+                yield " ".join(option)
+
     def convert_dialog(self, s, loc, toks):
         yield toks.block_id[0]
         yield " "
         yield toks.block_type
-        if toks.caption:
-            yield " "
-            yield toks.pre_caption
-            yield "CAPTION "  # The string caption
-
+        if toks.block_options:
             name = rc.generate_dialog_caption_name(toks.block_type, toks.block_id[0])
-            msgid = toks.caption[1:-1]
-            if msgid in self.inputdict:
-                if name in self.inputdict[msgid]:
-                    yield '"' + self.inputdict[msgid][name] + '"'
-                elif EMPTY_LOCATION in self.inputdict[msgid]:
-                    yield '"' + self.inputdict[msgid][EMPTY_LOCATION] + '"'
-            else:
-                yield toks.caption
-
-            yield from toks.post_caption  # The rest of the options
-            yield NL
-        else:
-            yield " "
-            yield from toks.post_caption  # The rest of the options
-            yield NL
+            yield from self.convert_block_options(s, loc, toks.block_options, name)
 
+        yield self.templatestore.newline
         yield BLOCK_START
-        yield NL
+        yield self.templatestore.newline
         addnl = False
 
         for c in toks.controls:
-
             if isinstance(c, str):
                 yield from self.convert_comment(addnl, c)
                 addnl = True
                 continue
             if addnl:
-                yield NL
+                yield self.templatestore.newline
                 addnl = False
             yield "    "
             c0 = c[0]
             if len(c0[0]) >= 16:
                 yield c0[0]
                 # If more than 16 char, put it on a new line to align it.
-                yield NL + " " * (16 + 4)
+                yield self.templatestore.newline + " " * (16 + 4)
             else:
                 yield c0[0].ljust(16)
 
@@ -128,9 +135,8 @@ class rerc:
                     tmp.append('"' + self.inputdict[msgid][name] + '"')
                 elif EMPTY_LOCATION in self.inputdict[msgid]:
                     tmp.append('"' + self.inputdict[msgid][EMPTY_LOCATION] + '"')
-            else:
-                if i > 1:
-                    tmp.append(" ".join(c[1:i]))
+            elif i > 1:
+                tmp.append(" ".join(c[1:i]))
 
             # and the remaining items, comma separated
             for a in c[i:]:
@@ -140,17 +146,20 @@ class rerc:
                     tmp.append(a)
 
             yield ",".join(tmp)
-            yield NL
+            yield self.templatestore.newline
 
+        if addnl:
+            yield self.templatestore.newline
+            addnl = False
         yield BLOCK_END
 
     def convert_string_table(self, s, loc, toks):
         yield toks[0]
-        if toks[1]:
-            yield f" {toks[1]}"
-        yield NL
+        if toks.block_options:
+            yield from self.convert_block_options(s, loc, toks.block_options)
+        yield self.templatestore.newline
         yield BLOCK_START
-        yield NL
+        yield self.templatestore.newline
 
         addnl = False
         for c in toks.controls:
@@ -159,13 +168,13 @@ class rerc:
                 addnl = True
                 continue
             if addnl:
-                yield NL
+                yield self.templatestore.newline
                 addnl = False
             yield "    "
             c0 = c[0]
             if len(c0[0]) >= 24:
                 yield c0[0]
-                yield NL + " " * (24 + 4)
+                yield self.templatestore.newline + " " * (24 + 4)
             else:
                 yield c0[0].ljust(24)
 
@@ -181,11 +190,14 @@ class rerc:
 
             for part in tmp[:-1]:
                 yield part
-                yield NL + " " * (24 + 4)
+                yield self.templatestore.newline + " " * (24 + 4)
             yield tmp[-1]
 
-            yield NL
+            yield self.templatestore.newline
 
+        if addnl:
+            yield self.templatestore.newline
+            addnl = False
         yield BLOCK_END
 
     def convert_language(self, s, loc, toks):
@@ -218,11 +230,11 @@ class rerc:
             yield ", "
             yield value
         yield from popup.post_caption  # The rest of the options
-        yield NL
+        yield self.templatestore.newline
 
         yield identation
         yield BLOCK_START
-        yield NL
+        yield self.templatestore.newline
 
         for element in popup.elements:
             if isinstance(element, str):
@@ -235,7 +247,6 @@ class rerc:
                 yield " "
 
                 if element.values_ and len(element.values_) >= 2:
-
                     name = rc.generate_menuitem_name(
                         pre_name, element.block_type, element.values_[1]
                     )
@@ -252,9 +263,9 @@ class rerc:
                 elif element.values_[0] == "SEPARATOR":
                     yield "SEPARATOR"
                 else:
-                    raise NotImplementedError()
+                    raise NotImplementedError
 
-                yield NL
+                yield self.templatestore.newline
 
             elif element.popups:
                 for sub_popup in element.popups:
@@ -265,20 +276,18 @@ class rerc:
                     )
         yield identation
         yield BLOCK_END
-        yield NL
+        yield self.templatestore.newline
 
     def convert_menu(self, s, loc, toks):
         yield toks.block_id[0]
         yield " "
         yield toks.block_type
 
-        # A menu can't have CAPTION, so don't try to translate it.
-        yield " "
-        yield from toks.post_caption  # The rest of the options
-        yield NL
+        yield from self.convert_block_options(s, loc, toks.block_options)
+        yield self.templatestore.newline
 
         yield BLOCK_START
-        yield NL
+        yield self.templatestore.newline
 
         pre_name = generate_menu_pre_name(toks.block_type, toks.block_id[0])
 
@@ -289,7 +298,6 @@ class rerc:
 
     def translate_strings(self, s, loc, toks):
         """Change the strings in the toks by the ones in the translation."""
-
         if toks.language:
             # Recreate the language, but using the settings.
             return list(self.convert_language(s, loc, toks))
@@ -310,13 +318,12 @@ class rerc:
         self.makestoredict(inputstore, includefuzzy)
         statement = rc.rc_statement()
         statement.add_parse_action(self.translate_strings)
-        return statement.transform_string(self.templatefile.read().decode(self.charset))
+        return statement.transform_string(self.templatecontent.decode(self.charset))
 
     def makestoredict(self, store, includefuzzy=False):
-        """make a dictionary of the translations"""
+        """Make a dictionary of the translations."""
         for unit in store.units:
             if includefuzzy or not unit.isfuzzy():
-
                 rcstring = unit.target
                 if len(rcstring.strip()) == 0:
                     rcstring = unit.source
@@ -359,9 +366,7 @@ def convertrc(
         raise ValueError("must specify a target language")
     if templatefile is None:
         raise ValueError("must have template file for rc files")
-        # convertor = po2rc()
-    else:
-        convertor = rerc(templatefile, charset, lang, sublang)
+    convertor = rerc(templatefile, charset, lang, sublang)
     outputrclines = convertor.convertstore(inputstore, includefuzzy)
     try:
         outputfile.write(outputrclines.encode("cp1252"))
