@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Convert .Net Resource (.resx) to Gettext PO localisation files.
+"""
+Convert .Net Resource (.resx) to Gettext PO localisation files.
 
 See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/resx2po.html
 for examples and usage instructions.
@@ -27,15 +28,14 @@ import logging
 
 from translate.storage import po
 
-
 logger = logging.getLogger(__name__)
 
 
 class resx2po:
-    """Convert a RESX file to a PO file for handling translation"""
+    """Convert a RESX file to a PO file for handling translation."""
 
     def convert_store(self, input_store, duplicatestyle="msgctxt"):
-        """Converts a RESX file to a PO file"""
+        """Converts a RESX file to a PO file."""
         output_store = po.pofile()
         output_header = output_store.init_headers(
             charset="UTF-8", encoding="8bit", x_accelerator_marker="&"
@@ -45,7 +45,6 @@ class resx2po:
             if input_unit.istranslatable():
                 output_unit = self.convert_unit(input_unit, "developer")
                 if output_unit is not None:
-
                     # Split out translator & dev comments before adding them
                     self.split_comments(output_unit, output_unit)
 
@@ -57,7 +56,7 @@ class resx2po:
     def merge_store(
         self, template_store, input_store, blankmsgstr=False, duplicatestyle="msgctxt"
     ):
-        """Converts two RESX files to a PO file"""
+        """Converts two RESX files to a PO file."""
         output_store = po.pofile()
         output_header = output_store.init_headers(
             charset="UTF-8", encoding="8bit", x_accelerator_marker="&"
@@ -109,8 +108,9 @@ class resx2po:
 
     @staticmethod
     def convert_unit(input_unit, commenttype):
-        """Converts a RESX unit to a PO unit
-        @return: None if empty or not for translation
+        """
+        Converts a RESX unit to a PO unit
+        @return: None if empty or not for translation.
         """
         if input_unit is None:
             return None
@@ -132,7 +132,6 @@ def convert_resx(
     duplicatestyle="msgctxt",
     filter=None,
 ):
-
     from translate.storage import resx
 
     input_store = resx.RESXFile(input_file)
