@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Convert XLIFF localization files to an OpenOffice.org (SDF) localization file.
+"""
+Convert XLIFF localization files to an OpenOffice.org (SDF) localization file.
 
 See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/oo2po.html
 for examples and usage instructions.
@@ -29,7 +30,6 @@ import time
 from translate.filters import autocorrect, checks, pofilter
 from translate.storage import factory, oo
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -43,7 +43,7 @@ class reoo:
         long_keys=False,
         filteraction="exclude",
     ):
-        """construct a reoo converter for the specified languages (timestamp=0 means leave unchanged)"""
+        """Construct a reoo converter for the specified languages (timestamp=0 means leave unchanged)."""
         # languages is a pair of language ids
         self.long_keys = long_keys
         self.readoo(templatefile)
@@ -60,14 +60,14 @@ class reoo:
         self.includefuzzy = includefuzzy
 
     def makeindex(self):
-        """makes an index of the oo keys that are used in the source file"""
+        """Makes an index of the oo keys that are used in the source file."""
         self.index = {}
         for ookey, theoo in self.o.ookeys.items():
             sourcekey = oo.makekey(ookey, self.long_keys)
             self.index[sourcekey] = theoo
 
     def readoo(self, of):
-        """read in the oo from the file"""
+        """Read in the oo from the file."""
         oosrc = of.read()
         self.o = oo.oofile()
         self.o.parse(oosrc)
@@ -75,36 +75,34 @@ class reoo:
 
     def handleunit(self, unit):
         # TODO: make this work for multiple columns in oo...
-        locations = unit.getlocations()
+        location = unit.getid()
         # technically our formats should just have one location for each entry...
-        # but we handle multiple ones just to be safe...
-        for location in locations:
-            subkeypos = location.rfind(".")
-            subkey = location[subkeypos + 1 :]
-            key = location[:subkeypos]
-            # this is just to handle our old system of using %s/%s:%s instead of %s/%s#%s
-            key = key.replace(":", "#")
-            # this is to handle using / instead of \ in the sourcefile...
-            key = key.replace("\\", "/")
-            key = oo.normalizefilename(key)
-            if key in self.index:
-                # now we need to replace the definition of entity with msgstr
-                theoo = self.index[key]  # find the oo
-                self.applytranslation(key, subkey, theoo, unit)
-            else:
-                logger.warning(
-                    "couldn't find key %s from po in %d keys", key, len(self.index)
-                )
-                try:
-                    sourceunitlines = str(unit)
-                    if isinstance(sourceunitlines, str):
-                        sourceunitlines = sourceunitlines.encode("utf-8")
-                    logger.warning(sourceunitlines)
-                except Exception:
-                    logger.error("error outputting source unit %r", str(unit))
+        subkeypos = location.rfind(".")
+        subkey = location[subkeypos + 1 :]
+        key = location[:subkeypos]
+        # this is just to handle our old system of using %s/%s:%s instead of %s/%s#%s
+        key = key.replace(":", "#")
+        # this is to handle using / instead of \ in the sourcefile...
+        key = key.replace("\\", "/")
+        key = oo.normalizefilename(key)
+        if key in self.index:
+            # now we need to replace the definition of entity with msgstr
+            theoo = self.index[key]  # find the oo
+            self.applytranslation(key, subkey, theoo, unit)
+        else:
+            logger.warning(
+                "couldn't find key %s from po in %d keys", key, len(self.index)
+            )
+            try:
+                sourceunitlines = str(unit)
+                if isinstance(sourceunitlines, str):
+                    sourceunitlines = sourceunitlines.encode("utf-8")
+                logger.warning(sourceunitlines)
+            except Exception:
+                logger.exception("error outputting source unit %r", str(unit))
 
     def applytranslation(self, key, subkey, theoo, unit):
-        """applies the translation from the source unit to the oo unit"""
+        """Applies the translation from the source unit to the oo unit."""
         if not self.includefuzzy and unit.isfuzzy():
             return
         makecopy = False
@@ -159,7 +157,7 @@ def getmtime(filename):
 
 class oocheckfilter(pofilter.pocheckfilter):
     def validelement(self, unit, filename, filteraction):
-        """Returns whether or not to use unit in conversion. (filename is just for error reporting)"""
+        """Returns whether or not to use unit in conversion. (filename is just for error reporting)."""
         if filteraction == "none":
             return True
         filterresult = self.filterunit(unit)
@@ -219,10 +217,7 @@ def convertoo(
     if not targetlanguage:
         raise ValueError("You must specify the target language")
     if not sourcelanguage:
-        if targetlanguage.isdigit():
-            sourcelanguage = "01"
-        else:
-            sourcelanguage = "en-US"
+        sourcelanguage = "01" if targetlanguage.isdigit() else "en-US"
     languages = (sourcelanguage, targetlanguage)
     if templatefile is None:
         raise ValueError("must have template file for oo files")
