@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2015 Zuza Software Foundation
 #
@@ -17,10 +16,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Assamese language.
-
-.. seealso:: https://en.wikipedia.org/wiki/Assamese_language
 """
+This module represents the Assamese language.
+
+.. seealso:: :wp:`Assamese_language`
+"""
+
 
 from translate.lang import common
 
@@ -29,14 +30,14 @@ class code_as(common.Common):
     """This class represents Assamese."""
 
     numbertuple = (
-        (u"0", u"০"),  # U+09E6 Bengali digit zero.
-        (u"1", u"১"),  # U+09E7 Bengali digit one.
-        (u"2", u"২"),  # U+09E8 Bengali digit two.
-        (u"3", u"৩"),  # U+09E9 Bengali digit three.
-        (u"4", u"৪"),  # U+09EA Bengali digit four.
-        (u"5", u"৫"),  # U+09EB Bengali digit five.
-        (u"6", u"৬"),  # U+09EC Bengali digit six.
-        (u"7", u"৭"),  # U+09ED Bengali digit seven.
-        (u"8", u"৮"),  # U+09EE Bengali digit eight.
-        (u"9", u"৯"),  # U+09EF Bengali digit nine.
+        ("0", "০"),  # U+09E6 Bengali digit zero.
+        ("1", "১"),  # U+09E7 Bengali digit one.
+        ("2", "২"),  # U+09E8 Bengali digit two.
+        ("3", "৩"),  # U+09E9 Bengali digit three.
+        ("4", "৪"),  # U+09EA Bengali digit four.
+        ("5", "৫"),  # U+09EB Bengali digit five.
+        ("6", "৬"),  # U+09EC Bengali digit six.
+        ("7", "৭"),  # U+09ED Bengali digit seven.
+        ("8", "৮"),  # U+09EE Bengali digit eight.
+        ("9", "৯"),  # U+09EF Bengali digit nine.
     )
