@@ -16,9 +16,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the the Danish language.
+"""
+This module represents the the Danish language.
 
-.. seealso:: https://en.wikipedia.org/wiki/Danish_language
+.. seealso:: :wp:`Danish_language`
 """
 
 
