@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007-2008, 2011 Zuza Software Foundation
 #
@@ -18,10 +16,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Armenian language.
-
-.. seealso:: http://en.wikipedia.org/wiki/Armenian_language
 """
+This module represents the Armenian language.
+
+.. seealso:: :wp:`Armenian_language`
+"""
+
 
 import re
 
@@ -31,30 +31,34 @@ from translate.lang import common
 class hy(common.Common):
     """This class represents Armenian."""
 
-    armenianpunc = u"։՝՜՞"
+    armenianpunc = "։՝՜՞"
 
-    punctuation = u"".join([common.Common.commonpunc, common.Common.quotes,
-                            common.Common.miscpunc, armenianpunc])
+    punctuation = f"{common.Common.commonpunc}{common.Common.quotes}{common.Common.miscpunc}{armenianpunc}"
 
-    sentenceend = u"։՝՜…"
+    sentenceend = "։՝՜…"
 
-    sentencere = re.compile(ur"""
+    sentencere = re.compile(
+        r"""
         (?s)        # make . also match newlines
         .*?         # anything, but match non-greedy
         [%s]        # the puntuation for sentence ending
         \s+         # the spacing after the puntuation
         (?=[^a-zա-ֆ\d])  # lookahead that next part starts with caps
-        """ % sentenceend, re.VERBOSE | re.UNICODE
+        """
+        % sentenceend,
+        re.VERBOSE | re.UNICODE,
     )
 
     puncdict = {
-        u".": u"։",
-        u":": u"՝",
-        u"!": u"՜",
-        u"?": u"՞",
+        ".": "։",
+        ":": "՝",
+        "!": "՜",
+        "?": "՞",
     }
 
-    ignoretests = ["startcaps", "simplecaps"]
+    ignoretests = {
+        "all": ["simplecaps", "startcaps"],
+    }
 
     mozilla_nplurals = 2
     mozilla_pluralequation = "n!=1 ? 1 : 0"
