@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008, 2016 Zuza Software Foundation
 #
@@ -17,12 +16,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Kannada language.
+"""
+This module represents the Kannada language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Kannada_language
+.. seealso:: :wp:`Kannada_language`
 """
 
-from __future__ import unicode_literals
 
 from translate.lang import common
 
@@ -31,5 +30,5 @@ class kn(common.Common):
     """This class represents Kannada."""
 
     ignoretests = {
-        'all': ["simplecaps", "startcaps"],
+        "all": ["simplecaps", "startcaps"],
     }
