@@ -1,3 +1,4 @@
+# noqa: N999
 #
 # Copyright 2016 Zuza Software Foundation
 #
@@ -15,10 +16,12 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
+#
 
-"""This module represents the Brazilian Portuguese language.
+"""
+This module represents the Brazilian Portuguese language.
 
-.. seealso:: https://en.wikipedia.org/wiki/Brazilian_Portuguese
+.. seealso:: :wp:`Brazilian_Portuguese`
 """
 
 
@@ -30,4 +33,4 @@ class pt_BR(Common):
 
     miscpunc = Common.miscpunc.replace("·", "")  # Middle dot is not valid.
 
-    validaccel = "ABCDEFGHIJKLMNOPQRSTUVXYZ" "abcdefghijklmnopqrstuvxyz" "1234567890"
+    validaccel = "ABCDEFGHIJKLMNOPQRSTUVXYZabcdefghijklmnopqrstuvxyz1234567890"
