@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Songhai languages.
+"""
+This module represents the Songhai languages.
 
 .. seealso:: :wp:`Songhai_languages`
 """
