@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Chinese language (simplified).
+"""
+This module represents the Chinese language (simplified).
 
 .. seealso:: :wp:`Chinese_language`
 """
