@@ -25,7 +25,8 @@ import sys
 
 
 def get_abs_data_filename(path_parts, basedirs=None):
-    """Get the absolute path to the given file- or directory name in the
+    """
+    Get the absolute path to the given file- or directory name in the
     current running application's data directory.
 
     :type  path_parts: list
@@ -76,4 +77,4 @@ def get_abs_data_filename(path_parts, basedirs=None):
         )
         if os.path.exists(datafile):
             return datafile
-    raise Exception('Could not find "%s"' % (os.path.join(*path_parts)))
+    raise ValueError('Could not find "%s"' % (os.path.join(*path_parts)))
