@@ -63,10 +63,10 @@ class ProgressBar:
 
 
 class ManPageOption(optparse.Option):
-    ACTIONS = optparse.Option.ACTIONS + ("manpage",)
+    ACTIONS = (*optparse.Option.ACTIONS, "manpage")
 
     def take_action(self, action, dest, opt, value, values, parser):
-        """take_action that can handle manpage as well as standard actions"""
+        """take_action that can handle manpage as well as standard actions."""
         if action == "manpage":
             parser.print_manpage()
             sys.exit(0)
@@ -90,10 +90,7 @@ class ManHelpFormatter(optparse.HelpFormatter):
             short_opts = option._short_opts
             long_opts = option._long_opts
 
-        if self.short_first:
-            opts = short_opts + long_opts
-        else:
-            opts = long_opts + short_opts
+        opts = short_opts + long_opts if self.short_first else long_opts + short_opts
 
         return "\\fB%s\\fP" % ("\\fR, \\fP".join(opts))
 
@@ -121,13 +118,13 @@ class RecursiveOptionParser(optparse.OptionParser):
     def __init__(
         self, formats, usetemplates=False, allowmissingtemplate=False, description=None
     ):
-        """Construct the specialized Option Parser.
+        """
+        Construct the specialized Option Parser.
 
         :type formats: Dictionary
         :param formats: See :meth:`~.RecursiveOptionParser.setformats`
         for an explanation of the formats parameter.
         """
-
         super().__init__(version="%prog " + __version__.sver, description=description)
         self.setmanpageoption()
         self.setprogressoptions()
@@ -141,8 +138,9 @@ class RecursiveOptionParser(optparse.OptionParser):
         return os.path.basename(sys.argv[0])
 
     def setmanpageoption(self):
-        """creates a manpage option that allows the optionparser to generate a
-        manpage
+        """
+        creates a manpage option that allows the optionparser to generate a
+        manpage.
         """
         manpageoption = ManPageOption(
             None,
@@ -155,15 +153,19 @@ class RecursiveOptionParser(optparse.OptionParser):
         self.define_option(manpageoption)
 
     def format_manpage(self):
-        """returns a formatted manpage"""
+        """Returns a formatted manpage."""
         result = []
         prog = self.get_prog_name()
-        formatprog = lambda x: x.replace("%prog", prog)
-        formatToolkit = lambda x: x.replace("%prog", "Translate Toolkit")
+
+        def formatprog(x):
+            return x.replace("%prog", prog)
+
+        def formatToolkit(x):
+            return x.replace("%prog", "Translate Toolkit")
+
         result.append('.\\" Autogenerated manpage\n')
         result.append(
-            '.TH %s 1 "%s" "" "%s"\n'
-            % (prog, formatToolkit(self.version), formatToolkit(self.version))
+            f'.TH {prog} 1 "{formatToolkit(self.version)}" "" "{formatToolkit(self.version)}"\n'
         )
         result.append(".SH NAME\n")
         result.append(
@@ -195,14 +197,15 @@ class RecursiveOptionParser(optparse.OptionParser):
         return "".join(result)
 
     def print_manpage(self, file=None):
-        """outputs a manpage for the program using the help information"""
+        """Outputs a manpage for the program using the help information."""
         if file is None:
             file = sys.stdout
         file.write(self.format_manpage())
 
     def set_usage(self, usage=None):
-        """sets the usage string - if usage not given, uses getusagestring for
-        each option
+        """
+        sets the usage string - if usage not given, uses getusagestring for
+        each option.
         """
         if usage is None:
             self.usage = "%prog " + " ".join(
@@ -232,7 +235,7 @@ class RecursiveOptionParser(optparse.OptionParser):
 
     @staticmethod
     def getusagestring(option):
-        """returns the usage string for the given option"""
+        """Returns the usage string for the given option."""
         optionstring = "|".join(option._short_opts + option._long_opts)
         if getattr(option, "optionalswitch", False):
             optionstring = "[%s]" % optionstring
@@ -240,12 +243,11 @@ class RecursiveOptionParser(optparse.OptionParser):
             optionstring += " " + option.metavar
         if getattr(option, "required", False):
             return optionstring
-        else:
-            return "[%s]" % optionstring
+        return "[%s]" % optionstring
 
     @staticmethod
     def getusageman(option):
-        """returns the usage string for the given option"""
+        """Returns the usage string for the given option."""
         optionstring = "\\fR|\\fP".join(option._short_opts + option._long_opts)
         if getattr(option, "optionalswitch", False):
             optionstring = "\\fR[\\fP%s\\fR]\\fP" % optionstring
@@ -253,11 +255,11 @@ class RecursiveOptionParser(optparse.OptionParser):
             optionstring += " \\fI%s\\fP" % option.metavar
         if getattr(option, "required", False):
             return optionstring
-        else:
-            return "\\fR[\\fP%s\\fR]\\fP" % optionstring
+        return "\\fR[\\fP%s\\fR]\\fP" % optionstring
 
     def define_option(self, option):
-        """Defines the given option, replacing an existing one of the same
+        """
+        Defines the given option, replacing an existing one of the same
         short name if neccessary...
         """
         for short_opt in option._short_opts:
@@ -269,7 +271,8 @@ class RecursiveOptionParser(optparse.OptionParser):
         self.add_option(option)
 
     def setformats(self, formats, usetemplates):
-        """Sets the format options using the given format dictionary.
+        """
+        Sets the format options using the given format dictionary.
 
         :type formats: Dictionary or iterable
         :param formats: The dictionary *keys* should be:
@@ -284,7 +287,6 @@ class RecursiveOptionParser(optparse.OptionParser):
                         The dictionary *values* should be tuples of
                         outputformat (string) and processor method.
         """
-
         self.inputformats = []
         outputformats = []
         templateformats = []
@@ -296,7 +298,7 @@ class RecursiveOptionParser(optparse.OptionParser):
             if isinstance(formatgroup, str) or formatgroup is None:
                 formatgroup = (formatgroup,)
             if not isinstance(formatgroup, tuple):
-                raise ValueError("formatgroups must be tuples or None/str/unicode")
+                raise TypeError("formatgroups must be tuples or None/str/unicode")
             if len(formatgroup) < 1 or len(formatgroup) > 2:
                 raise ValueError("formatgroups must be tuples of length 1 or 2")
             if len(formatgroup) == 1:
@@ -396,23 +398,22 @@ class RecursiveOptionParser(optparse.OptionParser):
         formats = sorted(f for f in formats if f is not None)
         if len(formats) == 0:
             return ""
-        elif len(formats) == 1:
+        if len(formats) == 1:
             return "%s format" % (", ".join(formats))
-        else:
-            return "%s formats" % (", ".join(formats))
+        return "%s formats" % (", ".join(formats))
 
     @staticmethod
     def isrecursive(fileoption, filepurpose="input"):
         """Checks if fileoption is a recursive file."""
         if fileoption is None:
             return False
-        elif isinstance(fileoption, list):
+        if isinstance(fileoption, list):
             return True
-        else:
-            return os.path.isdir(fileoption)
+        return os.path.isdir(fileoption)
 
     def parse_args(self, args=None, values=None):
-        """Parses the command line options, handling implicit input/output
+        """
+        Parses the command line options, handling implicit input/output
         args.
         """
         (options, args) = super().parse_args(args, values)
@@ -462,7 +463,7 @@ class RecursiveOptionParser(optparse.OptionParser):
             templateext = None
         if (inputext, templateext) in self.outputoptions:
             return self.outputoptions[inputext, templateext]
-        elif (inputext, "*") in self.outputoptions:
+        if (inputext, "*") in self.outputoptions:
             outputformat, fileprocessor = self.outputoptions[inputext, "*"]
         elif ("*", templateext) in self.outputoptions:
             outputformat, fileprocessor = self.outputoptions["*", templateext]
@@ -482,21 +483,17 @@ class RecursiveOptionParser(optparse.OptionParser):
                     raise ValueError(
                         "don't know what to do with input format (no file extension), no template file"
                     )
-                elif templateext is None:
+                if templateext is None:
                     raise ValueError(
                         "don't know what to do with input format %s, no template file"
                         % (os.extsep + inputext)
                     )
-                else:
-                    raise ValueError(
-                        "don't know what to do with input format %s, template format %s"
-                        % (os.extsep + inputext, os.extsep + templateext)
-                    )
-            else:
                 raise ValueError(
-                    "don't know what to do with input format %s"
-                    % (os.extsep + inputext)
+                    f"don't know what to do with input format {os.extsep + inputext}, template format {os.extsep + templateext}"
                 )
+            raise ValueError(
+                "don't know what to do with input format %s" % (os.extsep + inputext)
+            )
         if outputformat == "*":
             if inputext:
                 outputformat = inputext
@@ -509,10 +506,9 @@ class RecursiveOptionParser(optparse.OptionParser):
                     raise ValueError(
                         "don't know what to do with input format (no file extension), no template file"
                     )
-                else:
-                    raise ValueError(
-                        "don't know what to do with input format (no file extension)"
-                    )
+                raise ValueError(
+                    "don't know what to do with input format (no file extension)"
+                )
         return outputformat, fileprocessor
 
     @staticmethod
@@ -520,28 +516,26 @@ class RecursiveOptionParser(optparse.OptionParser):
         """Gets the full path to an input file."""
         if options.input:
             return os.path.join(options.input, inputpath)
-        else:
-            return inputpath
+        return inputpath
 
     @staticmethod
     def getfulloutputpath(options, outputpath):
         """Gets the full path to an output file."""
         if options.recursiveoutput and options.output:
             return os.path.join(options.output, outputpath)
-        else:
-            return outputpath
+        return outputpath
 
     def getfulltemplatepath(self, options, templatepath):
         """Gets the full path to a template file."""
         if not options.recursivetemplate:
             return templatepath
-        elif templatepath is not None and self.usetemplates and options.template:
+        if templatepath is not None and self.usetemplates and options.template:
             return os.path.join(options.template, templatepath)
-        else:
-            return None
+        return None
 
     def run(self):
-        """Parses the arguments, and runs recursiveprocess with the resulting
+        """
+        Parses the arguments, and runs recursiveprocess with the resulting
         options...
         """
         (options, args) = self.parse_args()
@@ -557,12 +551,11 @@ class RecursiveOptionParser(optparse.OptionParser):
                 inputfiles = self.recurseinputfilelist(options)
             else:
                 inputfiles = self.recurseinputfiles(options)
+        elif options.input:
+            inputfiles = [os.path.basename(options.input)]
+            options.input = os.path.dirname(options.input)
         else:
-            if options.input:
-                inputfiles = [os.path.basename(options.input)]
-                options.input = os.path.dirname(options.input)
-            else:
-                inputfiles = [options.input]
+            inputfiles = [options.input]
         options.recursiveoutput = self.isrecursive(
             options.output, "output"
         ) and getattr(options, "allowrecursiveoutput", True)
@@ -613,8 +606,7 @@ class RecursiveOptionParser(optparse.OptionParser):
                 )
             except Exception:
                 self.warning(
-                    "Error processing: input %s, output %s, template %s"
-                    % (fullinputpath, fulloutputpath, fulltemplatepath),
+                    f"Error processing: input {fullinputpath}, output {fulloutputpath}, template {fulltemplatepath}",
                     options,
                     sys.exc_info(),
                 )
@@ -667,8 +659,7 @@ class RecursiveOptionParser(optparse.OptionParser):
         if fulltemplatepath is not None:
             if os.path.isfile(fulltemplatepath):
                 return open(fulltemplatepath, "rb")
-            else:
-                self.warning("missing template file %s" % fulltemplatepath)
+            self.warning("missing template file %s" % fulltemplatepath)
         return None
 
     def processfile(
@@ -684,25 +675,30 @@ class RecursiveOptionParser(optparse.OptionParser):
             tempoutput = False
         templatefile = self.opentemplatefile(options, fulltemplatepath)
         passthroughoptions = self.getpassthroughoptions(options)
-        if fileprocessor(inputfile, outputfile, templatefile, **passthroughoptions):
+        result = fileprocessor(
+            inputfile, outputfile, templatefile, **passthroughoptions
+        )
+        if fullinputpath is not None:
+            inputfile.close()
+        if result:
             if tempoutput:
                 self.warning("writing to temporary output...")
                 self.finalizetempoutputfile(options, outputfile, fulloutputpath)
-            return True
-        else:
-            # remove the file if it is a file (could be stdout etc)
             if fulloutputpath and os.path.isfile(fulloutputpath):
                 outputfile.close()
-                os.unlink(fulloutputpath)
-            return False
+            return True
+        # remove the file if it is a file (could be stdout etc)
+        if fulloutputpath and os.path.isfile(fulloutputpath):
+            outputfile.close()
+            os.unlink(fulloutputpath)
+        return False
 
     @staticmethod
     def mkdir(parent, subdir):
         """Makes a subdirectory (recursively if neccessary)."""
         if not os.path.isdir(parent):
             raise ValueError(
-                "cannot make child directory %r if parent %r does not exist"
-                % (subdir, parent)
+                f"cannot make child directory {subdir!r} if parent {parent!r} does not exist"
             )
         currentpath = parent
         subparts = subdir.split(os.sep)
@@ -712,7 +708,8 @@ class RecursiveOptionParser(optparse.OptionParser):
                 os.mkdir(currentpath)
 
     def checkoutputsubdir(self, options, subdir):
-        """Checks to see if subdir under options.output needs to be created,
+        """
+        Checks to see if subdir under options.output needs to be created,
         creates if neccessary.
         """
         fullpath = os.path.join(options.output, subdir)
@@ -774,7 +771,8 @@ class RecursiveOptionParser(optparse.OptionParser):
 
     @staticmethod
     def splitext(pathname):
-        """Splits *pathname* into name and ext, and removes the extsep.
+        """
+        Splits *pathname* into name and ext, and removes the extsep.
 
         :param pathname: A file path
         :type pathname: string
@@ -814,7 +812,7 @@ class RecursiveOptionParser(optparse.OptionParser):
                             return templatepath
             if "*" in self.inputformats:
                 for inputext1, templateext1 in self.outputoptions:
-                    if (inputext == inputext1) or (inputext1 == "*"):
+                    if inputext1 in (inputext, "*"):
                         if templateext1 == "*":
                             templatepath = inputname
                             if self.templateexists(options, templatepath):
