@@ -18,31 +18,31 @@
 
 """Base classes for storage interfaces."""
 
-from collections import OrderedDict
+from __future__ import annotations
+
 import codecs
 import logging
 import pickle
 from io import BytesIO
 
 from translate.misc.multistring import multistring
-from translate.storage.placeables import StringElem, parse as rich_parse
+from translate.storage.placeables import StringElem
+from translate.storage.placeables import parse as rich_parse
 from translate.storage.workflow import StateEnum as states
 
-
 # Simple BOM based encoding detection
 ENCODING_BOMS = (
-    (codecs.BOM_UTF8, 'utf-8-sig'),
-    (codecs.BOM_UTF16, 'utf-16'),
-    (codecs.BOM_UTF16_BE, 'utf-16-be'),
-    (codecs.BOM_UTF16_LE, 'utf-16-le'),
-    (codecs.BOM_UTF32, 'utf-32'),
-    (codecs.BOM_UTF32_BE, 'utf-32-be'),
-    (codecs.BOM_UTF32_LE, 'utf-32-le'),
+    (codecs.BOM_UTF8, "utf-8-sig"),
+    (codecs.BOM_UTF16, "utf-16"),
+    (codecs.BOM_UTF16_BE, "utf-16-be"),
+    (codecs.BOM_UTF16_LE, "utf-16-le"),
+    (codecs.BOM_UTF32, "utf-32"),
+    (codecs.BOM_UTF32_BE, "utf-32-be"),
+    (codecs.BOM_UTF32_LE, "utf-32-le"),
 )
 
 
 class ParseError(Exception):
-
     def __init__(self, inner_exc):
         self.inner_exc = inner_exc
 
@@ -51,7 +51,8 @@ class ParseError(Exception):
 
 
 class TranslationUnit:
-    """Base class for translation units.
+    """
+    Base class for translation units.
 
     Our concept of a *translation unit* is influenced heavily by `XLIFF
     <http://docs.oasis-open.org/xliff/xliff-core/xliff-core.html>`_.
@@ -125,7 +126,8 @@ class TranslationUnit:
             self.source = source
 
     def __eq__(self, other):
-        """Compares two TranslationUnits.
+        """
+        Compares two TranslationUnits.
 
         :type other: :class:`TranslationUnit`
         :param other: Another :class:`TranslationUnit`
@@ -133,7 +135,11 @@ class TranslationUnit:
         :return: Returns *True* if the supplied :class:`TranslationUnit`
                  equals this unit.
         """
-        return self.source == other.source and self.target == other.target
+        return (
+            self.source == other.source
+            and self.target == other.target
+            and self.getid() == other.getid()
+        )
 
     def __ne__(self, other):
         return not self.__eq__(other)
@@ -144,29 +150,37 @@ class TranslationUnit:
     def __str__(self):
         """Converts to a string representation. Most often overriden by subclasses."""
         # no point in showing store object.
-        return ", ".join([
-            "%s: %s" % (k, self.__dict__[k]) for k in sorted(self.__dict__.keys()) if k != '_store'
-        ])
+        return ", ".join(
+            f"{k}: {self.__dict__[k]}"
+            for k in sorted(self.__dict__.keys())
+            if k != "_store"
+        )
 
     @classmethod
     def rich_to_multistring(cls, elem_list):
-        """Convert a "rich" string tree to a ``multistring``:
+        """
+        Convert a "rich" string tree to a ``multistring``.
 
-        >>> from translate.storage.placeables.interfaces import X
-        >>> rich = [StringElem(['foo', X(id='xxx', sub=[' ']), 'bar'])]
-        >>> TranslationUnit.rich_to_multistring(rich)
-        multistring('foo bar')
+        .. code-block:: pycon
+
+            >>> from translate.storage.placeables.interfaces import X
+            >>> rich = [StringElem(['foo', X(id='xxx', sub=[' ']), 'bar'])]
+            >>> TranslationUnit.rich_to_multistring(rich)
+            multistring('foo bar')
         """
         return multistring([str(elem) for elem in elem_list])
 
     def multistring_to_rich(self, mulstring):
-        """Convert a multistring to a list of "rich" string trees:
+        """
+        Convert a multistring to a list of "rich" string trees.
 
-        >>> target = multistring(['foo', 'bar', 'baz'])
-        >>> TranslationUnit.multistring_to_rich(target)
-        [<StringElem([<StringElem(['foo'])>])>,
-         <StringElem([<StringElem(['bar'])>])>,
-         <StringElem([<StringElem(['baz'])>])>]
+        .. code-block:: pycon
+
+            >>> target = multistring(['foo', 'bar', 'baz'])
+            >>> TranslationUnit.multistring_to_rich(target)
+            [<StringElem([<StringElem(['foo'])>])>,
+             <StringElem([<StringElem(['bar'])>])>,
+             <StringElem([<StringElem(['baz'])>])>]
         """
         if isinstance(mulstring, multistring):
             return [rich_parse(s, self.rich_parsers) for s in mulstring.strings]
@@ -194,21 +208,19 @@ class TranslationUnit:
 
     @property
     def rich_source(self):
-        """
-        .. seealso:: :meth:`.rich_to_multistring`, :meth:`multistring_to_rich`
-        """
+        """.. seealso:: :meth:`.rich_to_multistring`, :meth:`multistring_to_rich`."""
         if self._rich_source is None:
             self._rich_source = self.multistring_to_rich(self.source)
         return self._rich_source
 
     @rich_source.setter
     def rich_source(self, value):
-        if not hasattr(value, '__iter__'):
-            raise ValueError('value must be iterable')
+        if not hasattr(value, "__iter__"):
+            raise ValueError("value must be iterable")
         if len(value) < 1:
-            raise ValueError('value must have at least one element.')
+            raise ValueError("value must have at least one element.")
         if not isinstance(value[0], StringElem):
-            raise ValueError('value[0] must be of type StringElem.')
+            raise TypeError("value[0] must be of type StringElem.")
         self._rich_source = list(value)
         multi = self.rich_to_multistring(value)
         if self.source != multi:
@@ -216,26 +228,25 @@ class TranslationUnit:
 
     @property
     def rich_target(self):
-        """
-        .. seealso:: :meth:`.rich_to_multistring`, :meth:`.multistring_to_rich`
-        """
+        """.. seealso:: :meth:`.rich_to_multistring`, :meth:`.multistring_to_rich`."""
         if self._rich_target is None:
             self._rich_target = self.multistring_to_rich(self.target)
         return self._rich_target
 
     @rich_target.setter
     def rich_target(self, value):
-        if not hasattr(value, '__iter__'):
-            raise ValueError('value must be iterable')
+        if not hasattr(value, "__iter__"):
+            raise ValueError("value must be iterable")
         if len(value) < 1:
-            raise ValueError('value must have at least one element.')
+            raise ValueError("value must have at least one element.")
         if not isinstance(value[0], StringElem):
-            raise ValueError('value[0] must be of type StringElem.')
+            raise TypeError("value[0] must be of type StringElem.")
         self._rich_target = list(value)
         self.target = self.rich_to_multistring(value)
 
     def gettargetlen(self):
-        """Returns the length of the target string.
+        """
+        Returns the length of the target string.
 
         :rtype: Integer
 
@@ -246,11 +257,12 @@ class TranslationUnit:
         length = len(self.target or "")
         strings = getattr(self.target, "strings", [])
         if strings:
-            length += sum([len(pluralform) for pluralform in strings[1:]])
+            length += sum(len(pluralform) for pluralform in strings[1:])
         return length
 
     def getid(self):
-        """A unique identifier for this unit.
+        """
+        A unique identifier for this unit.
 
         :rtype: string
         :return: an identifier for this unit that is unique in the store
@@ -261,15 +273,17 @@ class TranslationUnit:
         return self.source
 
     def setid(self, value):
-        """Sets the unique identified for this unit.
+        """
+        Sets the unique identified for this unit.
 
         only implemented if format allows ids independant from other unit
         properties like source or context
         """
-        pass
 
-    def getlocations(self):
-        """A list of source code locations.
+    @staticmethod
+    def getlocations():
+        """
+        A list of source code locations.
 
         :rtype: List
 
@@ -280,16 +294,17 @@ class TranslationUnit:
         return []
 
     def addlocation(self, location):
-        """Add one location to the list of locations.
+        """
+        Add one location to the list of locations.
 
         .. note::
 
            Shouldn't be implemented if the format doesn't support it.
         """
-        pass
 
     def addlocations(self, location):
-        """Add a location or a list of locations.
+        """
+        Add a location or a list of locations.
 
         .. note::
 
@@ -306,16 +321,17 @@ class TranslationUnit:
         else:
             self.addlocation(location)
 
-    def getcontext(self):
+    @staticmethod
+    def getcontext():
         """Get the message context."""
         return ""
 
     def setcontext(self, context):
-        """Set the message context"""
-        pass
+        """Set the message context."""
 
     def getnotes(self, origin=None):
-        """Returns all notes about this unit.
+        """
+        Returns all notes about this unit.
 
         It will probably be freeform text or something reasonable that can be
         synthesised by the format.
@@ -325,7 +341,8 @@ class TranslationUnit:
         return getattr(self, "notes", "")
 
     def addnote(self, text, origin=None, position="append"):
-        """Adds a note (comment).
+        """
+        Adds a note (comment).
 
         :type text: string
         :param text: Usually just a sentence or two.
@@ -336,41 +353,44 @@ class TranslationUnit:
                        - 'developer', 'programmer', 'source code' (synonyms)
         """
         if position == "append" and getattr(self, "notes", None):
-            self.notes += '\n' + text
+            self.notes += "\n" + text
         else:
             self.notes = text
 
     def removenotes(self, origin=None):
         """Remove all the translator's notes."""
-        self.notes = ''
+        self.notes = ""
 
     def adderror(self, errorname, errortext):
-        """Adds an error message to this unit.
+        """
+        Adds an error message to this unit.
 
         :type errorname: string
         :param errorname: A single word to id the error.
         :type errortext: string
         :param errortext: The text describing the error.
         """
-        pass
 
-    def geterrors(self):
-        """Get all error messages.
+    @staticmethod
+    def geterrors():
+        """
+        Get all error messages.
 
         :rtype: Dictionary
         """
         return {}
 
     def markreviewneeded(self, needsreview=True, explanation=None):
-        """Marks the unit to indicate whether it needs review.
+        """
+        Marks the unit to indicate whether it needs review.
 
         :keyword needsreview: Defaults to True.
         :keyword explanation: Adds an optional explanation as a note.
         """
-        pass
 
     def istranslated(self):
-        """Indicates whether this unit is translated.
+        """
+        Indicates whether this unit is translated.
 
         This should be used rather than deducing it from .target,
         to ensure that other classes can implement more functionality
@@ -379,39 +399,43 @@ class TranslationUnit:
         return bool(self.target) and not self.isfuzzy()
 
     def istranslatable(self):
-        """Indicates whether this unit can be translated.
+        """
+        Indicates whether this unit can be translated.
 
         This should be used to distinguish real units for translation from
         header, obsolete, binary or other blank units.
         """
         return bool(self.source)
 
-    def isfuzzy(self):
+    @staticmethod
+    def isfuzzy():
         """Indicates whether this unit is fuzzy."""
         return False
 
     def markfuzzy(self, value=True):
         """Marks the unit as fuzzy or not."""
-        pass
 
-    def isobsolete(self):
-        """indicate whether a unit is obsolete"""
+    @staticmethod
+    def isobsolete():
+        """Indicate whether a unit is obsolete."""
         return False
 
     def makeobsolete(self):
-        """Make a unit obsolete"""
-        pass
+        """Make a unit obsolete."""
 
-    def isheader(self):
+    @staticmethod
+    def isheader():
         """Indicates whether this unit is a header."""
         return False
 
-    def isreview(self):
+    @staticmethod
+    def isreview():
         """Indicates whether this unit needs review."""
         return False
 
     def isblank(self):
-        """Used to see if this unit has no source or target string.
+        """
+        Used to see if this unit has no source or target string.
 
         .. note::
 
@@ -421,9 +445,10 @@ class TranslationUnit:
         """
         return not (self.source or self.target)
 
-    def hasplural(self):
+    @staticmethod
+    def hasplural():
         """Tells whether or not this specific unit has plural strings."""
-        #TODO: Reconsider
+        # TODO: Reconsider
         return False
 
     def getsourcelanguage(self):
@@ -432,8 +457,7 @@ class TranslationUnit:
     def gettargetlanguage(self):
         return self._store.gettargetlanguage()
 
-    def merge(self, otherunit, overwrite=False, comments=True,
-              authoritative=False):
+    def merge(self, otherunit, overwrite=False, comments=True, authoritative=False):
         """Do basic format agnostic merging."""
         if not self.target or overwrite:
             self.rich_target = otherunit.rich_target
@@ -448,14 +472,17 @@ class TranslationUnit:
 
     @classmethod
     def buildfromunit(cls, unit):
-        """Build a native unit from a foreign unit, preserving as much
-        information as possible.
         """
-        if type(unit) == cls and hasattr(unit, "copy") and callable(unit.copy):
+        Build a native unit from a foreign unit.
+
+        Preserving as much information as possible.
+        """
+        if type(unit) is cls and hasattr(unit, "copy") and callable(unit.copy):
             return unit.copy()
         newunit = cls(unit.source)
         newunit.target = unit.target
         newunit.markfuzzy(unit.isfuzzy())
+        newunit.setid(unit.getid())
         locations = unit.getlocations()
         if locations:
             newunit.addlocations(locations)
@@ -474,29 +501,26 @@ class TranslationUnit:
             if state_range[0] <= n < state_range[1]:
                 return state_id
         if self.STATE:
-            raise ValueError('No state containing value %s' % (n))
-        else:
-            return n
+            raise ValueError("No state containing value %s" % (n))
+        return n
 
     def get_state_n(self):
         if self.STATE:
             return self._state_n
-        else:
-            return self.istranslated() and self.S_UNREVIEWED or self.S_EMPTY
+        return self.S_UNREVIEWED if self.istranslated() else self.S_EMPTY
 
     def set_state_n(self, value):
         self._state_n = value
 
     def infer_state(self):
-        """Empty method that should be overridden in sub-classes to infer the
+        """
+        Empty method that should be overridden in sub-classes to infer the
         current state(_n) of the unit from its current state.
         """
-        pass
 
 
 class TranslationStore:
-    """Base class for stores for multiple translation units of type UnitClass.
-    """
+    """Base class for stores for multiple translation units of type UnitClass."""
 
     UnitClass = TranslationUnit
     """The class of units that will be instantiated and used by this class"""
@@ -512,7 +536,7 @@ class TranslationStore:
     """Indicates if format can store suggestions and alternative translation
     for a unit"""
 
-    default_encoding = 'utf-8'
+    default_encoding = "utf-8"
     sourcelanguage = None
     targetlanguage = None
 
@@ -529,16 +553,16 @@ class TranslationStore:
     @property
     def encoding(self):
         # self._encoding is either defined by __init__ or auto-detected from parsed file
-        if self._encoding == 'auto':
-            return 'utf-8'
+        if self._encoding == "auto":
+            return "utf-8"
         return self._encoding or self.default_encoding
 
     @encoding.setter
     def encoding(self, value):
         if value == "CHARSET" or value is None:
             return
-        if value == 'ascii':
-            value = 'utf-8'
+        if value == "ascii":
+            value = "utf-8"
         self._encoding = value
 
     def getsourcelanguage(self):
@@ -559,7 +583,7 @@ class TranslationStore:
 
     def getprojectstyle(self):
         """Get the project type for this store."""
-        return getattr(self, '_project_style', None)
+        return getattr(self, "_project_style", None)
 
     def setprojectstyle(self, project_style):
         """Set the project type for this store."""
@@ -567,15 +591,15 @@ class TranslationStore:
 
     def unit_iter(self):
         """Iterator over all the units in this store."""
-        for unit in self.units:
-            yield unit
+        yield from self.units
 
     def getunits(self):
         """Return a list of all units in this store."""
-        return [unit for unit in self.unit_iter()]
+        return list(self.unit_iter())
 
     def addunit(self, unit):
-        """Append the given unit to the object's list of units.
+        """
+        Append the given unit to the object's list of units.
 
         This method should always be used rather than trying to modify the
         list manually.
@@ -587,7 +611,8 @@ class TranslationStore:
         self.units.append(unit)
 
     def removeunit(self, unit):
-        """Remove the given unit to the object's list of units.
+        """
+        Remove the given unit to the object's list of units.
 
         This method should always be used rather than trying to modify the
         list manually.
@@ -599,7 +624,8 @@ class TranslationStore:
         self.remove_unit_from_index(unit)
 
     def addsourceunit(self, source):
-        """Add and returns a new unit with the given source string.
+        """
+        Add and returns a new unit with the given source string.
 
         :rtype: :class:`TranslationUnit`
         """
@@ -608,12 +634,13 @@ class TranslationStore:
         return unit
 
     def findid(self, id):
-        """find unit with matching id by checking id_index"""
+        """Find unit with matching id by checking id_index."""
         self.require_index()
-        return self.id_index.get(id, None)
+        return self.id_index.get(id)
 
     def findunit(self, source):
-        """Find the unit with the given source string.
+        """
+        Find the unit with the given source string.
 
         :rtype: :class:`TranslationUnit` or None
         """
@@ -623,7 +650,8 @@ class TranslationStore:
         return None
 
     def findunits(self, source):
-        """Find the units with the given source string.
+        """
+        Find the units with the given source string.
 
         :rtype: :class:`TranslationUnit` or None
         """
@@ -633,24 +661,24 @@ class TranslationStore:
         return None
 
     def translate(self, source):
-        """Return the translated string for a given source string.
+        """
+        Return the translated string for a given source string.
 
         :rtype: String or None
         """
         unit = self.findunit(source)
         if unit and unit.target:
             return unit.target
-        else:
-            return None
+        return None
 
     def remove_unit_from_index(self, unit):
-        """Remove a unit from source and locaton indexes"""
+        """Remove a unit from source and locaton indexes."""
 
         def remove_source(source):
             if source in self.sourceindex:
                 self.sourceindex[source].remove(unit)
                 if len(self.sourceindex[source]) == 0:
-                    del(self.sourceindex[source])
+                    del self.sourceindex[source]
 
         if unit.hasplural():
             for source in unit.source.strings:
@@ -659,13 +687,15 @@ class TranslationStore:
             remove_source(unit.source)
 
         for location in unit.getlocations():
-            if (location in self.locationindex and
-                self.locationindex[location] is not None and
-                self.locationindex[location] == unit):
-                del(self.locationindex[location])
+            if (
+                location in self.locationindex
+                and self.locationindex[location] is not None
+                and self.locationindex[location] == unit
+            ):
+                del self.locationindex[location]
 
     def add_unit_to_index(self, unit):
-        """Add a unit to source and location idexes"""
+        """Add a unit to source and location idexes."""
         self.id_index[unit.getid()] = unit
 
         def insert_unit(source):
@@ -683,12 +713,13 @@ class TranslationStore:
         for location in unit.getlocations():
             # If locations aren't unique, keep the first unit.
             if location not in self.locationindex:
-                #FIXME: maybe better store a list of units like sourceindex in
+                # FIXME: maybe better store a list of units like sourceindex in
                 # case there are several units with the same location.
                 self.locationindex[location] = unit
 
     def makeindex(self):
-        """Indexes the items in this store. At least .sourceindex should be
+        """
+        Indexes the items in this store. At least .sourceindex should be
         useful.
         """
         self.locationindex = {}
@@ -700,19 +731,19 @@ class TranslationStore:
                 self.add_unit_to_index(unit)
 
     def require_index(self):
-        """make sure source index exists"""
+        """Make sure source index exists."""
         if not self.id_index:
             self.makeindex()
 
-    def getids(self, filename=None):
-        """return a list of unit ids"""
+    def getids(self):
+        """Return a list of unit ids."""
         self.require_index()
         return self.id_index.keys()
 
     def __getstate__(self):
         odict = self.__dict__.copy()
         # fileobj is generally not picklable
-        odict['fileobj'] = None
+        odict["fileobj"] = None
         return odict
 
     def __bytes__(self):
@@ -721,7 +752,8 @@ class TranslationStore:
         return out.getvalue()
 
     def serialize(self, out):
-        """Converts to a bytes representation that can be parsed back using
+        """
+        Converts to a bytes representation that can be parsed back using
         :meth:`~.TranslationStore.parsestring`.
         `out` should be an open file-like objects to write to.
         """
@@ -731,13 +763,11 @@ class TranslationStore:
         """Return True if the object doesn't contain any translation units."""
         if len(self.units) == 0:
             return True
-        for unit in self.units:
-            if unit.istranslatable():
-                return False
-        return True
+        return all(not unit.istranslatable() for unit in self.units)
 
     def _assignname(self):
-        """Tries to work out what the name of the filesystem file is and
+        """
+        Tries to work out what the name of the filesystem file is and
         assigns it to .filename.
         """
         fileobj = getattr(self, "fileobj", None)
@@ -758,63 +788,66 @@ class TranslationStore:
         newstore.parse(storestring)
         return newstore
 
-    def fallback_detection(self, text):
-        """
-        Simple detection based on BOM in case chardet is not available.
-        """
+    @staticmethod
+    def fallback_detection(text):
+        """Simple detection based on BOM in case chardet is not available."""
         for bom, encoding in ENCODING_BOMS:
             if text.startswith(bom):
-                return {
-                    'encoding': encoding,
-                    'confidence': 1.0
-                }
+                return {"encoding": encoding, "confidence": 1.0}
         return None
 
-    def detect_encoding(self, text, default_encodings=None):
+    def detect_encoding(
+        self, text: bytes, default_encodings: list[str] | None = None
+    ) -> tuple[str, str]:
         """
         Try to detect a file encoding from `text`, using either the chardet lib
         or by trying to decode the file.
         """
         if not default_encodings:
-            default_encodings = ['utf-8']
+            default_encodings = ["utf-8"]
         try:
-            import chardet
+            from charset_normalizer import detect
         except ImportError:
             detected_encoding = self.fallback_detection(text)
         else:
-            # many false complaints with ellipse (…) (see bug 1825)
-            detected_encoding = chardet.detect(text.replace(b"\xe2\x80\xa6", b""))
-            if detected_encoding['confidence'] < 0.48:
+            detected_encoding = detect(text)
+            if (
+                detected_encoding["confidence"] is None
+                or detected_encoding["confidence"] < 0.48
+            ):
                 detected_encoding = None
-            elif detected_encoding['encoding'] == 'ascii':
-                detected_encoding['encoding'] = self.encoding
+            elif detected_encoding["encoding"] == "ascii":
+                detected_encoding["encoding"] = self.encoding
             else:
-                detected_encoding['encoding'] = detected_encoding['encoding'].lower()
+                detected_encoding["encoding"] = detected_encoding["encoding"].lower()
 
         encodings = []
         # Purposefully accessed the internal _encoding, as encoding is never 'auto'
-        if self._encoding == 'auto':
-            if detected_encoding and detected_encoding['encoding'] not in encodings:
-                encodings.append(detected_encoding['encoding'])
+        if self._encoding == "auto":
+            if detected_encoding and detected_encoding["encoding"] not in encodings:
+                encodings.append(detected_encoding["encoding"])
             for encoding in default_encodings:
                 if encoding not in encodings:
                     encodings.append(encoding)
         elif detected_encoding:
-            if '-' in detected_encoding['encoding']:
-                encoding, suffix = detected_encoding['encoding'].rsplit('-', 1)
+            if "-" in detected_encoding["encoding"]:
+                encoding, suffix = detected_encoding["encoding"].rsplit("-", 1)
             else:
-                encoding = detected_encoding['encoding']
+                encoding = detected_encoding["encoding"]
                 suffix = None
 
             # Different charset, just with BOM
-            if encoding == self.encoding and suffix == 'sig':
-                encodings.append(detected_encoding['encoding'])
-            elif detected_encoding['encoding'] != self.encoding:
-                logging.warning("trying to parse %s with encoding: %s but "
-                                "detected encoding is %s (confidence: %s)",
-                                self.filename, self.encoding,
-                                detected_encoding['encoding'],
-                                detected_encoding['confidence'])
+            if encoding == self.encoding and suffix == "sig":
+                encodings.append(detected_encoding["encoding"])
+            elif detected_encoding["encoding"] != self.encoding:
+                logging.warning(
+                    "trying to parse %s with encoding: %s but "
+                    "detected encoding is %s (confidence: %s)",
+                    self.filename,
+                    self.encoding,
+                    detected_encoding["encoding"],
+                    detected_encoding["confidence"],
+                )
             encodings.append(self.encoding)
         else:
             encodings.append(self.encoding)
@@ -827,48 +860,47 @@ class TranslationStore:
             except UnicodeDecodeError:
                 r_text = None
                 r_encoding = None
-        if r_encoding == 'ascii':
-            r_encoding = 'utf-8'
+        if r_encoding == "ascii":
+            r_encoding = "utf-8"
         return r_text, r_encoding
 
     def parse(self, data):
-        """parser to process the given source string"""
+        """Parser to process the given source string."""
         self.units = pickle.loads(data).units
 
     def savefile(self, storefile):
         """Write the string representation to the given file (or filename)."""
         if isinstance(storefile, str):
-            storefile = open(storefile, 'wb')
+            storefile = open(storefile, "wb")
         self.fileobj = storefile
         self._assignname()
         self.serialize(storefile)
         storefile.close()
 
     def save(self):
-        """Save to the file that data was originally read from, if available.
-        """
+        """Save to the file that data was originally read from, if available."""
         fileobj = getattr(self, "fileobj", None)
         if not fileobj:
             if hasattr(self, "filename"):
-                fileobj = open(self.filename, 'wb')
+                fileobj = open(self.filename, "wb")
         else:
             fileobj.close()
-            filename = getattr(fileobj, "name",
-                               getattr(fileobj, "filename", None))
+            filename = getattr(fileobj, "name", getattr(fileobj, "filename", None))
             if not filename:
                 raise ValueError("No file or filename to save to")
-            fileobj = open(filename, 'wb')
+            fileobj = open(filename, "wb")
         self.savefile(fileobj)
 
     @classmethod
     def parsefile(cls, storefile):
-        """Reads the given file (or opens the given filename) and parses back
+        """
+        Reads the given file (or opens the given filename) and parses back
         to an object.
         """
         if isinstance(storefile, str):
-            storefile = open(storefile, 'rb')
-        mode = getattr(storefile, "mode", 'rb')
-        #For some reason GzipFile returns 1, so we have to test for that here
+            storefile = open(storefile, "rb")
+        mode = getattr(storefile, "mode", "rb")
+        # For some reason GzipFile returns 1, so we have to test for that here
         if mode == 1 or "r" in mode:
             storestring = storefile.read()
             storefile.close()
@@ -882,7 +914,8 @@ class TranslationStore:
 
     @property
     def merge_on(self):
-        """The matching criterion to use when merging on.
+        """
+        The matching criterion to use when merging on.
 
         :return: The default matching criterion for all the subclasses.
         :rtype: string
@@ -899,81 +932,112 @@ class UnitId:
 
     def __str__(self):
         def fmt(element, key):
-            if element == 'key':
-                return '{}{}'.format(self.KEY_SEPARATOR, key)
-            elif element == 'index':
-                return '{}[{}]'.format(self.INDEX_SEPARATOR, key)
-            else:
-                raise ValueError('Unsupported element: {}'.format(element))
-        return ''.join([fmt(*part) for part in self.parts])
+            if element == "key":
+                return f"{self.KEY_SEPARATOR}{key}"
+            if element == "index":
+                return f"{self.INDEX_SEPARATOR}[{key}]"
+            raise ValueError(f"Unsupported element: {element}")
 
-    def __add__(self, other):
-        if not isinstance(other, list):
-            raise ValueError('Not supported type for add: {}'.format(type(other)))
-        return self.__class__(self.parts + other)
+        return "".join(fmt(*part) for part in self.parts)
+
+    def extend(self, key, value):
+        return self.__class__([*self.parts, (key, value)])
 
     @classmethod
     def from_string(cls, text):
         result = []
         # Strip possible leading separator
         if text.startswith(cls.KEY_SEPARATOR):
-            text = text[len(cls.KEY_SEPARATOR):]
+            text = text[len(cls.KEY_SEPARATOR) :]
         for item in text.split(cls.KEY_SEPARATOR):
-            if '[' in item and item[-1] == ']':
-                item, pos = item[:-1].split('[')
-                if cls.INDEX_SEPARATOR and item:
-                    result.append(("key", item))
-                result.append(("index", int(pos)))
-            else:
+            bracepos = item.find("[")
+            endbracepos = item.find("]")
+            while (
+                (bracepos := item.find("[")) != -1
+                and (endbracepos := item.find("]")) != -1
+                and item[bracepos + 1 : endbracepos].isdigit()
+            ):
+                if bracepos > 0:
+                    result.append(("key", item[:bracepos]))
+                    item = item[bracepos:]
+                    endbracepos -= bracepos
+                    bracepos = 0
+                result.append(("index", int(item[bracepos + 1 : endbracepos])))
+                item = item[endbracepos + 1 :]
+            if item:
                 result.append(("key", item))
+        if not result:
+            result.append(("key", ""))
         return cls(result)
 
+    def __eq__(self, other):
+        return self.parts == other.parts
+
+    def __repr__(self):
+        return f"<UnitId:{self.parts}>"
+
 
 class DictUnit(TranslationUnit):
     IdClass = UnitId
-    DefaultDict = OrderedDict
 
     def __init__(self, source=None):
         super().__init__(source)
         self._unitid = None
 
-    def storevalue(self, output, value, override_key=None, unset=False):
-        target = output
+    def get_unitid(self):
         if self._unitid is None:
             self._unitid = self.IdClass.from_string(self._id)
-        parts = self._unitid.parts
+        return self._unitid
+
+    def storevalue(self, output, value, override_key=None, unset=False):
+        parent = target = output
+        parts = self.get_unitid().parts
+        key = None
         for pos, part in enumerate(parts[:-1]):
             element, key = part
-            default = [] if parts[pos + 1][0] == 'index' else self.DefaultDict()
-            if element == 'index':
-                if len(target) <= key and not unset:
-                    target.append(default)
-            elif element == 'key':
+            use_list = parts[pos + 1][0] == "index"
+            default = [] if use_list else {}
+            if element == "index":
+                while len(target) <= key and not unset:
+                    target.append(default.copy())
+            elif element == "key":
                 if key not in target or isinstance(target[key], str):
                     target[key] = default
             else:
-                raise ValueError('Unsupported element: {}'.format(element))
+                raise ValueError(f"Unsupported element: {element}")
+            if not use_list and isinstance(target[key], list):
+                # Convert list to dict if needed
+                target[key] = dict(enumerate(target[key]))
+            # Handle placeholders
+            if target[key] is None:
+                target[key] = default.copy()
+            parent = target
             target = target[key]
         if override_key:
-            element, key = 'key', override_key
+            child_element, child_key = "key", override_key
         else:
-            element, key = parts[-1]
-        if element == 'key':
+            child_element, child_key = parts[-1]
+        if child_element == "key":
             if unset:
-                del target[key]
+                del target[child_key]
+                # Remove empty dict from parent
+                if not target and key:
+                    del parent[key]
             else:
-                target[key] = value
-        elif element == 'index':
-            if len(target) <= key:
+                target[child_key] = value
+        elif child_element == "index":
+            if len(target) <= child_key:
                 if not unset:
+                    # Add placeholders to the list
+                    while len(target) < child_key:
+                        target.append(None)
                     target.append(value)
+            elif unset:
+                del target[child_key]
             else:
-                if unset:
-                    del target[key]
-                else:
-                    target[key] = value
+                target[child_key] = value
         else:
-            raise ValueError('Unsupported element: {}'.format(element))
+            raise ValueError(f"Unsupported element: {child_element}")
 
     def storevalues(self, output):
         self.storevalue(output, self.value)
@@ -984,12 +1048,22 @@ class DictUnit(TranslationUnit):
         self.storevalues(result)
         return result
 
-    def set_unitid(self, unitid):
-        self.setid(str(unitid))
+    def setid(self, value, unitid=None):
+        self._id = value
         self._unitid = unitid
 
+    def set_unitid(self, unitid):
+        # Set _unitid first to avoid need to re-construct it from id
+        self.setid(str(unitid), unitid)
+
 
 class DictStore(TranslationStore):
+    def get_root_node(self):
+        if self.units and all(
+            unit.get_unitid().parts[0][0] == "index" for unit in self.units
+        ):
+            return []
+        return {}
 
     def serialize_units(self, output):
         for unit in self.unit_iter():
