@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""factory methods to build real storage objects that conform to base.py"""
+"""factory methods to build real storage objects that conform to base.py."""
 
 import os
 from functools import lru_cache
@@ -25,7 +25,6 @@ from importlib import import_module
 from translate.storage.base import TranslationStore
 from translate.storage.directory import Directory
 
-
 # TODO: Monolingual formats (with template?)
 
 decompressclass = {
@@ -67,7 +66,7 @@ _ext is a pseudo extension, that is their is no real extension by that name.
 
 
 def _examine_txt(storefile):
-    """Determine the true filetype for a .txt file"""
+    """Determine the true filetype for a .txt file."""
     if isinstance(storefile, str) and os.path.exists(storefile):
         storefile = open(storefile, "rb")
     try:
@@ -77,10 +76,7 @@ def _examine_txt(storefile):
     # Some encoding magic for Wordfast
     from translate.storage import wordfast
 
-    if wordfast.TAB_UTF16 in start.split(b"\n")[0]:
-        encoding = "utf-16"
-    else:
-        encoding = "iso-8859-1"
+    encoding = "utf-16" if wordfast.TAB_UTF16 in start.split(b"\n")[0] else "iso-8859-1"
     start = start.decode(encoding)
     if "%Wordfast TM" in start:
         pseudo_extension = "_wftm"
@@ -96,7 +92,8 @@ _hiddenclasses = {"txt": _examine_txt}
 
 
 def _guessextention(storefile):
-    """Guesses the type of a file object by looking at the first few
+    """
+    Guesses the type of a file object by looking at the first few
     characters.  The return value is a file extention.
     """
     start = storefile.read(300).strip()
@@ -119,14 +116,15 @@ def _guessextention(storefile):
 
 
 def _getdummyname(storefile):
-    """Provides a dummy name for a file object without a name attribute, by
+    """
+    Provides a dummy name for a file object without a name attribute, by
     guessing the file type.
     """
     return "dummy." + _guessextention(storefile)
 
 
 def _getname(storefile):
-    """returns the filename"""
+    """Returns the filename."""
     if storefile is None:
         raise ValueError(
             "This method cannot magically produce a filename when given None as input."
@@ -157,7 +155,8 @@ def getclass(
     classes_str=None,
     hiddenclasses=None,
 ):
-    """Factory that returns the applicable class for the type of file
+    """
+    Factory that returns the applicable class for the type of file
     presented.  Specify ignore to ignore some part at the back of the name
     (like .gz).
     """
@@ -203,7 +202,8 @@ def getobject(
     classes_str=None,
     hiddenclasses=None,
 ):
-    """Factory that returns a usable object for the type of file presented.
+    """
+    Factory that returns a usable object for the type of file presented.
 
     :type storefile: file or str or TranslationStore
     :param storefile: File object or file name.
@@ -275,7 +275,8 @@ supported = [
 
 
 def supported_files():
-    """Returns data about all supported files
+    """
+    Returns data about all supported files.
 
     :return: list of type that include (name, extensions, mimetypes)
     :rtype: list
