@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Class that manages .ini files for translation
+"""
+Class that manages .ini files for translation.
 
 .. note::: A simple summary of what is permissible follows.
 
@@ -34,13 +35,18 @@ from io import StringIO
 
 from translate.storage import base
 
-
 try:
-    from iniparse import INIConfig
+    from iniparse import INIConfig, change_comment_syntax
 except ImportError:
     raise ImportError("Missing iniparse library.")
 
 
+location_re = re.compile("\\[(?P<section>.+)\\](?P<entry>.+)")
+
+# Disable treating anything starting with rem as a comment, this changes
+# global iniparse state
+change_comment_syntax(allow_rem=False)
+
 dialects = {}
 
 
@@ -51,7 +57,7 @@ def register_dialect(dialect):
 
 
 class Dialect:
-    """Base class for differentiating dialect options and functions"""
+    """Base class for differentiating dialect options and functions."""
 
     name = None
 
@@ -81,14 +87,14 @@ class DialectInno(DialectDefault):
 
 
 class iniunit(base.TranslationUnit):
-    """A INI file entry"""
+    """A INI file entry."""
 
     def __init__(self, source=None, **kwargs):
         if source:
             self.source = source
             self.location = f"[default]{hex(hash(source))}"
         else:
-            self.location = f"[default]{str(uuid.uuid4())}"
+            self.location = f"[default]{uuid.uuid4()!s}"
         super().__init__(source)
 
     def addlocation(self, location):
@@ -107,12 +113,12 @@ class iniunit(base.TranslationUnit):
 
 
 class inifile(base.TranslationStore):
-    """An INI file"""
+    """An INI file."""
 
     UnitClass = iniunit
 
     def __init__(self, inputfile=None, dialect="default", **kwargs):
-        """construct an INI file, optionally reading in from inputfile."""
+        """Construct an INI file, optionally reading in from inputfile."""
         self._dialect = dialects.get(
             dialect, DialectDefault
         )()  # fail correctly/use getattr/
@@ -126,7 +132,7 @@ class inifile(base.TranslationStore):
         _outinifile = self._inifile or INIConfig(optionxformvalue=None)
         for unit in self.units:
             for location in unit.getlocations():
-                match = re.match("\\[(?P<section>.+)\\](?P<entry>.+)", location)
+                match = location_re.match(location)
                 if match is None:
                     section = "default"
                     entry = location
