@@ -37,7 +37,6 @@ class RESXUnit(lisa.LISAunit):
 
     def createlanguageNode(self, lang, text, purpose):
         """Returns an xml Element setup with given parameters."""
-
         langset = etree.Element(self.namespaced(self.languageNode))
 
         langset.text = text
@@ -70,7 +69,7 @@ class RESXUnit(lisa.LISAunit):
         targetnode.text = target or ""
 
     def addnote(self, text, origin=None, position="append"):
-        """Add a note specifically in the appropriate "comment" tag"""
+        """Add a note specifically in the appropriate "comment" tag."""
         current_notes = self.getnotes(origin)
         self.removenotes(origin)
         note = etree.SubElement(self.xmlelement, self.namespaced("comment"))
@@ -223,6 +222,8 @@ class RESXFile(lisa.LISAfile):
             unit.xmlelement.text = "\n    "
         return unit
 
-    def serialize_hook(self, treestring):
+    def serialize_hook(self, treestring: str) -> bytes:
         # Additional space on empty tags same as Visual Studio
-        return treestring.replace(b"/>", b" />")
+        return super().serialize_hook(
+            treestring.replace("/>", " />").replace("\n", "\r\n")
+        )
