@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""module for handling TBX glossary files"""
+"""module for handling TBX glossary files."""
 
 from lxml import etree
 
@@ -25,7 +25,8 @@ from translate.storage import lisa
 
 
 class tbxunit(lisa.LISAunit):
-    """A single term in the TBX file.  Provisional work is done to make several
+    """
+    A single term in the TBX file.  Provisional work is done to make several
     languages possible.
     """
 
@@ -34,7 +35,7 @@ class tbxunit(lisa.LISAunit):
     textNode = "term"
 
     def createlanguageNode(self, lang, text, purpose):
-        """returns a langset xml Element setup with given parameters"""
+        """Returns a langset xml Element setup with given parameters."""
         langset = etree.Element(self.languageNode)
         setXMLlang(langset, lang)
         tig = etree.SubElement(langset, "tig")  # or ntig with termGrp inside
@@ -51,14 +52,21 @@ class tbxunit(lisa.LISAunit):
     def setid(self, value):
         return self.xmlelement.set("id", value)
 
+    def _get_origin_element(self, origin: str):
+        if origin == "pos":
+            return self.namespaced("termNote")
+        if origin == "definition":
+            return self.namespaced("descrip")
+        return self.namespaced("note")
+
     def removenotes(self, origin=None):
         """Remove all the translator notes."""
-        notes = self.xmlelement.iterdescendants(self.namespaced("note"))
+        notes = self.xmlelement.iterdescendants(self._get_origin_element(origin))
         for note in notes:
             self.xmlelement.remove(note)
 
     def addnote(self, text, origin=None, position="append"):
-        """Add a note specifically in a "note" tag"""
+        """Add a note specifically in a "note" tag."""
         if position != "append":
             self.removenotes(origin=origin)
 
@@ -66,32 +74,28 @@ class tbxunit(lisa.LISAunit):
             text = text.strip()
         if not text:
             return
-        note = etree.SubElement(self.xmlelement, self.namespaced("note"))
+        note = etree.SubElement(self.xmlelement, self._get_origin_element(origin))
         note.text = text
-        if origin:
+        if origin and origin not in ("pos", "definition"):
             note.set("from", origin)
 
     def _getnotelist(self, origin=None):
-        """Returns the text from notes matching ``origin`` or all notes.
+        """
+        Returns the text from notes matching ``origin`` or all notes.
 
         :param origin: The origin of the note (or note type)
         :type origin: String
         :return: The text from notes matching ``origin``
         :rtype: List
         """
-        note_nodes = []
-        if origin == "pos":
-            note_nodes = self.xmlelement.iterdescendants(self.namespaced("termNote"))
-        elif origin == "definition":
-            note_nodes = self.xmlelement.iterdescendants(self.namespaced("descrip"))
-        else:
-            note_nodes = self.xmlelement.iterdescendants(self.namespaced("note"))
+        note_nodes = self.xmlelement.iterdescendants(self._get_origin_element(origin))
         # TODO: consider using xpath to construct initial_list directly
         # or to simply get the correct text from the outset (just remember to
         # check for duplication.
         initial_list = [
             lisa.getText(note, getXMLspace(self.xmlelement, self._default_xml_space))
             for note in note_nodes
+            if origin in ("pos", "definition", None) or note.get("from") == origin
         ]
 
         # Remove duplicate entries from list:
@@ -126,7 +130,6 @@ class tbxfile(lisa.LISAfile):
 <text><body></body></text>
 </martif>"""
     XMLindent = {"indent": "    ", "toplevel": False}
-    XMLdoublequotes = True
 
     def addheader(self):
         """Initialise headers with TBX specific things."""
