@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Manage the Wordfast Translation Memory format
+"""
+Manage the Wordfast Translation Memory format.
 
 Wordfast TM format is the Translation Memory format used by the
 `Wordfast <http://www.wordfast.net/>`_ computer aided translation tool.
@@ -83,7 +84,6 @@ import time
 
 from translate.storage import base
 
-
 WF_TIMEFORMAT = "%Y%m%d~%H%M%S"
 """Time format used by Wordfast"""
 
@@ -185,7 +185,8 @@ TAB_UTF16 = b"\x00\x09"
 
 
 def _char_to_wf(string):
-    """Char -> Wordfast &'XX; escapes
+    r"""
+    Char -> Wordfast &'XX; escapes.
 
     Full roundtripping is not possible because of the escaping of
     NEWLINE \\n and TAB \\t
@@ -200,7 +201,7 @@ def _char_to_wf(string):
 
 
 def _wf_to_char(string):
-    """Wordfast &'XX; escapes -> Char"""
+    """Wordfast &'XX; escapes -> Char."""
     if string:
         for code, char in WF_ESCAPE_MAP:
             string = string.replace(code, char)
@@ -220,7 +221,7 @@ csv.register_dialect("wordfast", WordfastDialect)
 
 
 class WordfastTime:
-    """Manages time stamps in the Wordfast format of YYYYMMDD~hhmmss"""
+    """Manages time stamps in the Wordfast format of YYYYMMDD~hhmmss."""
 
     def __init__(self, newtime=None):
         self._time = None
@@ -232,14 +233,14 @@ class WordfastTime:
             self.time = newtime
 
     def get_timestring(self):
-        """Get the time in the Wordfast time format"""
+        """Get the time in the Wordfast time format."""
         if not self._time:
             return None
-        else:
-            return time.strftime(WF_TIMEFORMAT, self._time)
+        return time.strftime(WF_TIMEFORMAT, self._time)
 
     def set_timestring(self, timestring):
-        """Set the time_sturct object using a Wordfast time formated string
+        """
+        Set the time_sturct object using a Wordfast time formated string.
 
         :param timestring: A Wordfast time string (YYYMMDD~hhmmss)
         :type timestring: String
@@ -249,11 +250,12 @@ class WordfastTime:
     timestring = property(get_timestring, set_timestring)
 
     def get_time(self):
-        """Get the time_struct object"""
+        """Get the time_struct object."""
         return self._time
 
     def set_time(self, newtime):
-        """Set the time_struct object
+        """
+        Set the time_struct object.
 
         :param newtime: a new time object
         :type newtime: time.time_struct
@@ -268,12 +270,11 @@ class WordfastTime:
     def __str__(self):
         if not self.timestring:
             return ""
-        else:
-            return self.timestring
+        return self.timestring
 
 
 class WordfastHeader:
-    """A wordfast translation memory header"""
+    """A wordfast translation memory header."""
 
     def __init__(self, header=None):
         self._header_dict = []
@@ -284,8 +285,9 @@ class WordfastHeader:
 
     @staticmethod
     def _create_default_header():
-        """Create a default Wordfast header with the date set to the current
-        time
+        """
+        Create a default Wordfast header with the date set to the current
+        time.
         """
         defaultheader = {}
         defaultheader.update(WF_FIELDNAMES_HEADER_DEFAULTS)
@@ -293,7 +295,7 @@ class WordfastHeader:
         return defaultheader
 
     def getheader(self):
-        """Get the header dictionary"""
+        """Get the header dictionary."""
         return self._header_dict
 
     def setheader(self, newheader):
@@ -313,7 +315,7 @@ class WordfastHeader:
 
 
 class WordfastUnit(base.TranslationUnit):
-    """A Wordfast translation memory unit"""
+    """A Wordfast translation memory unit."""
 
     def __init__(self, source=None):
         self._dict = {}
@@ -322,15 +324,16 @@ class WordfastUnit(base.TranslationUnit):
         super().__init__(source)
 
     def _update_timestamp(self):
-        """Refresh the timestamp for the unit"""
+        """Refresh the timestamp for the unit."""
         self._dict["date"] = WordfastTime(time.localtime()).timestring
 
     def getdict(self):
-        """Get the dictionary of values for a Wordfast line"""
+        """Get the dictionary of values for a Wordfast line."""
         return self._dict
 
     def setdict(self, newdict):
-        """Set the dictionary of values for a Wordfast line
+        """
+        Set the dictionary of values for a Wordfast line.
 
         :param newdict: a new dictionary with Wordfast line elements
         :type newdict: Dict
@@ -343,10 +346,9 @@ class WordfastUnit(base.TranslationUnit):
     def _get_source_or_target(self, key):
         if self._dict.get(key, None) is None:
             return None
-        elif self._dict[key]:
+        if self._dict[key]:
             return _wf_to_char(self._dict[key])
-        else:
-            return ""
+        return ""
 
     def _set_source_or_target(self, key, newvalue):
         if newvalue is None:
@@ -389,7 +391,7 @@ class WordfastUnit(base.TranslationUnit):
 
 
 class WordfastTMFile(base.TranslationStore):
-    """A Wordfast translation memory file"""
+    """A Wordfast translation memory file."""
 
     Name = "Wordfast Translation Memory"
     Mimetypes = ["application/x-wordfast"]
@@ -398,7 +400,7 @@ class WordfastTMFile(base.TranslationStore):
     default_encoding = "iso-8859-1"
 
     def __init__(self, inputfile=None, **kwargs):
-        """construct a Wordfast TM, optionally reading in from inputfile."""
+        """Construct a Wordfast TM, optionally reading in from inputfile."""
         super().__init__(**kwargs)
         self.filename = ""
         self.header = WordfastHeader()
@@ -406,7 +408,7 @@ class WordfastTMFile(base.TranslationStore):
             self.parse(inputfile)
 
     def parse(self, input):
-        """parsese the given file or file source string"""
+        """Parsese the given file or file source string."""
         if hasattr(input, "name"):
             self.filename = input.name
         elif not getattr(self, "filename", ""):
