@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008-2010 Zuza Software Foundation
 #
@@ -21,32 +20,38 @@
 from translate.storage import xliff
 
 
-class XPathTree(object):
-
+class XPathTree:
     def __init__(self, unit=None):
         self.unit = unit
         self.children = {}
 
     def __eq__(self, other):
-        return (isinstance(other, XPathTree) and self.unit == other.unit and
-                self.children == other.children)
+        return (
+            isinstance(other, XPathTree)
+            and self.unit == other.unit
+            and self.children == other.children
+        )
 
 
 def _split_xpath_component(xpath_component):
-    """Split an xpath component into a tag-index tuple.
+    """
+    Split an xpath component into a tag-index tuple.
 
     >>> split_xpath_component('{urn:oasis:names:tc:opendocument:xmlns:office:1.0}document-content[0]')
     ('{urn:oasis:names:tc:opendocument:xmlns:office:1.0}document-content', 0).
     """
-    lbrac = xpath_component.rfind(u'[')
-    rbrac = xpath_component.rfind(u']')
+    lbrac = xpath_component.rfind("[")
+    rbrac = xpath_component.rfind("]")
     tag = xpath_component[:lbrac]
-    index = int(xpath_component[lbrac+1:rbrac])
+    index = int(xpath_component[lbrac + 1 : rbrac])
     return tag, index
 
 
 def _split_xpath(xpath):
-    """Split an 'xpath' string separated by / into a reversed list of its components. Thus:
+    """
+    Split an 'xpath' string separated by / into a reversed list of its components.
+
+    Thus:
 
     >>> split_xpath('document-content[1]/body[2]/text[3]/p[4]')
     [('p', 4), ('text', 3), ('body', 2), ('document-content', 1)]
@@ -56,13 +61,14 @@ def _split_xpath(xpath):
     """
     if xliff.ID_SEPARATOR in xpath:
         xpath = xpath.split(xliff.ID_SEPARATOR)[-1]
-    components = xpath.split(u'/')
+    components = xpath.split("/")
     components = [_split_xpath_component(component) for component in components]
     return list(reversed(components))
 
 
 def _add_unit_to_tree(node, xpath_components, unit):
-    """Walk down the tree rooted a node, and follow nodes which correspond to the
+    """
+    Walk down the tree rooted a node, and follow nodes which correspond to the
     components of xpath_components. When reaching the end of xpath_components,
     set the reference of the node to unit.
 
@@ -81,7 +87,9 @@ def _add_unit_to_tree(node, xpath_components, unit):
     components left to pop. Thus, ``node.unit = unit`` is executed.
     """
     if len(xpath_components) > 0:
-        component = xpath_components.pop()  # pop the stack; is a component such as ('p', 4)
+        component = (
+            xpath_components.pop()
+        )  # pop the stack; is a component such as ('p', 4)
         # if the current node does not have any children indexed by
         # the current component, add such a child
         if component not in node.children:
@@ -92,7 +100,8 @@ def _add_unit_to_tree(node, xpath_components, unit):
 
 
 def build_unit_tree(store, filename=None):
-    """Enumerate a translation store and build a tree with XPath components as nodes
+    """
+    Enumerate a translation store and build a tree with XPath components as nodes
     and where a node contains a unit if a path from the root of the tree to the node
     containing the unit, is equal to the XPath of the unit.
 
@@ -112,11 +121,11 @@ def build_unit_tree(store, filename=None):
                        `- <reference to a unit>
     """
     tree = XPathTree()
+    is_xliff = isinstance(store, xliff.xlifffile)
     for unit in store.units:
         if unit.source and not unit.isfuzzy():
-            locations = unit.getlocations()
-            if (filename is not None and len(locations) > 1 and
-                filename != locations[1]):
+            locations = [unit.getid()] if is_xliff else unit.getlocations()
+            if filename is not None and len(locations) > 1 and filename != locations[1]:
                 # Skip units that don't come from the filename we are currently
                 # trying to get units for.
                 # This is not used for ODF, right now only for IDML.
