@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008 Zuza Software Foundation
 #
@@ -18,7 +17,6 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 """Import units from translations files into tmdb."""
-from __future__ import print_function
 
 import logging
 import os
@@ -26,12 +24,10 @@ from argparse import ArgumentParser
 
 from translate.storage import factory, tmdb
 
-
 logger = logging.getLogger(__name__)
 
 
 class Builder:
-
     def __init__(self, tmdbfile, source_lang, target_lang, filenames):
         self.tmdb = tmdb.TMDB(tmdbfile)
         self.source_lang = source_lang
@@ -41,7 +37,7 @@ class Builder:
             if not os.path.exists(filename):
                 logger.error("cannot process %s: does not exist", filename)
                 continue
-            elif os.path.isdir(filename):
+            if os.path.isdir(filename):
                 self.handledir(filename)
             else:
                 self.handlefile(filename)
@@ -50,8 +46,8 @@ class Builder:
     def handlefile(self, filename):
         try:
             store = factory.getobject(filename)
-        except Exception as e:
-            logger.error(str(e))
+        except Exception:
+            logger.exception("Failed to handle file")
             return
         # do something useful with the store and db
         try:
@@ -79,17 +75,27 @@ class Builder:
 def main():
     parser = ArgumentParser()
     parser.add_argument(
-        "-d", "--tmdb", dest="tmdb_file", default="tm.db",
-        help="translation memory database file (default: %(default)s)")
-    parser.add_argument(
-        "-s", "--import-source-lang", dest="source_lang", default="en",
-        help="source language of translation files (default: %(default)s)")
-    parser.add_argument(
-        "-t", "--import-target-lang", dest="target_lang",
-        help="target language of translation files", required=True)
-    parser.add_argument(
-        "files", metavar="input files", nargs="+"
+        "-d",
+        "--tmdb",
+        dest="tmdb_file",
+        default="tm.db",
+        help="translation memory database file (default: %(default)s)",
     )
+    parser.add_argument(
+        "-s",
+        "--import-source-lang",
+        dest="source_lang",
+        default="en",
+        help="source language of translation files (default: %(default)s)",
+    )
+    parser.add_argument(
+        "-t",
+        "--import-target-lang",
+        dest="target_lang",
+        help="target language of translation files",
+        required=True,
+    )
+    parser.add_argument("files", metavar="input files", nargs="+")
     args = parser.parse_args()
 
     logging.basicConfig(format="%(name)s: %(levelname)s: %(message)s")
@@ -97,5 +103,5 @@ def main():
     Builder(args.tmdb_file, args.source_lang, args.target_lang, args.files)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
