@@ -16,8 +16,9 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""diff tool like GNU diff, but lets you have special options that are useful
-in dealing with PO files
+"""
+diff tool like GNU diff, but lets you have special options that are useful
+in dealing with PO files.
 """
 
 import difflib
@@ -27,12 +28,11 @@ import sys
 import time
 from argparse import ArgumentParser
 
-
 lineterm = "\n"
 
 
 def main():
-    """main program for pydiff"""
+    """Main program for pydiff."""
     parser = ArgumentParser()
     # GNU diff like options
     parser.add_argument(
@@ -135,40 +135,38 @@ def main():
             differ = DirDiffer(fromfile, tofile, args)
         else:
             parser.error(
-                "File %s is a directory while file %s is a regular file"
-                % (fromfile, tofile)
+                f"File {fromfile} is a directory while file {tofile} is a regular file"
             )
+    elif os.path.isdir(tofile):
+        parser.error(
+            f"File {fromfile} is a regular file while file {tofile} is a directory"
+        )
     else:
-        if os.path.isdir(tofile):
-            parser.error(
-                "File %s is a regular file while file %s is a directory"
-                % (fromfile, tofile)
-            )
-        else:
-            differ = FileDiffer(fromfile, tofile, args)
+        differ = FileDiffer(fromfile, tofile, args)
     differ.writediff(sys.stdout)
 
 
 class DirDiffer:
-    """generates diffs between directories"""
+    """generates diffs between directories."""
 
     def __init__(self, fromdir, todir, options):
-        """Constructs a comparison between the two dirs using the
-        given options
+        """
+        Constructs a comparison between the two dirs using the
+        given options.
         """
         self.fromdir = fromdir
         self.todir = todir
         self.options = options
 
     def isexcluded(self, difffile):
-        """checks if the given filename has been excluded from the diff"""
+        """Checks if the given filename has been excluded from the diff."""
         return any(
             fnmatch.fnmatch(difffile, exclude_pat)
             for exclude_pat in self.options.exclude
         )
 
     def writediff(self, outfile):
-        """writes the actual diff to the given file"""
+        """Writes the actual diff to the given file."""
         fromfiles = os.listdir(self.fromdir)
         tofiles = os.listdir(self.todir)
         difffiles = dict.fromkeys(fromfiles + tofiles).keys()
@@ -192,23 +190,19 @@ class DirDiffer:
                             differ.writediff(outfile)
                         else:
                             outfile.write(
-                                "Common subdirectories: %s and %s\n"
-                                % (fromfile, tofile)
+                                f"Common subdirectories: {fromfile} and {tofile}\n"
                             )
                     else:
                         outfile.write(
-                            "File %s is a directory while file %s is a regular file\n"
-                            % (fromfile, tofile)
+                            f"File {fromfile} is a directory while file {tofile} is a regular file\n"
                         )
+                elif os.path.isdir(tofile):
+                    outfile.write(
+                        f"File {fromfile} is a regular file while file {tofile} is a directory\n"
+                    )
                 else:
-                    if os.path.isdir(tofile):
-                        outfile.write(
-                            "File %s is a regular file while file %s is a directory\n"
-                            % (fromfile, tofile)
-                        )
-                    else:
-                        filediffer = FileDiffer(fromfile, tofile, self.options)
-                        filediffer.writediff(outfile)
+                    filediffer = FileDiffer(fromfile, tofile, self.options)
+                    filediffer.writediff(outfile)
             elif from_ok:
                 outfile.write(f"Only in {self.fromdir}: {difffile}\n")
             elif to_ok:
@@ -216,18 +210,19 @@ class DirDiffer:
 
 
 class FileDiffer:
-    """generates diffs between files"""
+    """generates diffs between files."""
 
     def __init__(self, fromfile, tofile, options):
-        """Constructs a comparison between the two files using the given
-        options
+        """
+        Constructs a comparison between the two files using the given
+        options.
         """
         self.fromfile = fromfile
         self.tofile = tofile
         self.options = options
 
     def writediff(self, outfile):
-        """writes the actual diff to the given file"""
+        """Writes the actual diff to the given file."""
         validfiles = True
         if os.path.exists(self.fromfile):
             with open(self.fromfile) as fh:
@@ -318,22 +313,23 @@ class FileDiffer:
             outfile.write(f"Files {self.fromfile} and {self.tofile} are identical\n")
 
     def get_from_lines(self, group):
-        """returns the lines referred to by group, from the fromfile"""
+        """Returns the lines referred to by group, from the fromfile."""
         from_lines = []
         for tag, i1, i2, j1, j2 in group:
             from_lines.extend(self.from_lines[i1:i2])
         return from_lines
 
     def get_to_lines(self, group):
-        """returns the lines referred to by group, from the tofile"""
+        """Returns the lines referred to by group, from the tofile."""
         to_lines = []
         for tag, i1, i2, j1, j2 in group:
             to_lines.extend(self.to_lines[j1:j2])
         return to_lines
 
     def unified_diff(self, group):
-        """takes the group of opcodes and generates a unified diff line
-        by line
+        """
+        takes the group of opcodes and generates a unified diff line
+        by line.
         """
         i1, i2, j1, j2 = group[0][1], group[-1][2], group[0][3], group[-1][4]
         yield "@@ -%d,%d +%d,%d @@%s" % (i1 + 1, i2 - i1, j1 + 1, j2 - j1, lineterm)
